@@ -22,43 +22,58 @@
 #ifndef BEING_H
 #define BEING_H
 
-#include <list>
-#include <memory>
-#include <string>
-#include <SDL_types.h>
-#include <set>
+#include <guichan/color.hpp>
 
+#include <SDL_types.h>
+
+#include <set>
+#include <string>
+#include <vector>
+
+#include "configlistener.h"
+#include "map.h"
+#include "particlecontainer.h"
 #include "position.h"
 #include "sprite.h"
-#include "map.h"
-#include "animatedsprite.h"
-#include "particlecontainer.h"
+#include "vector.h"
+
+#include "resources/spritedef.h"
 
 #define FIRST_IGNORE_EMOTE 14
 #define STATUS_EFFECTS 32
 
+#define SPEECH_TIME 500
+#define SPEECH_MAX_TIME 1000
+
 class AnimatedSprite;
-class Equipment;
+class Image;
 class ItemInfo;
 class Item;
 class Map;
 class Graphics;
-class ImageSet;
 class Particle;
+class Position;
+class SimpleAnimation;
+class SpeechBubble;
 class Text;
 
 class StatusEffect;
 
-enum Gender {
+typedef std::list<Sprite*> Sprites;
+typedef Sprites::iterator SpriteIterator;
+
+enum Gender
+{
     GENDER_MALE = 0,
     GENDER_FEMALE = 1,
     GENDER_UNSPECIFIED = 2
 };
 
-class Being : public Sprite
+class Being : public Sprite, public ConfigListener
 {
     public:
-        enum Type {
+        enum Type
+        {
             UNKNOWN,
             PLAYER,
             NPC,
@@ -66,9 +81,12 @@ class Being : public Sprite
         };
 
         /**
-         * Action the being is currently performing.
+         * Action the being is currently performing
+         * WARNING: Has to be in sync with the same enum in the Being class
+         * of the server!
          */
-        enum Action {
+        enum Action
+        {
             STAND,
             WALK,
             ATTACK,
@@ -77,52 +95,81 @@ class Being : public Sprite
             HURT
         };
 
-        enum Sprite {
+        enum Sprite
+        {
             BASE_SPRITE = 0,
             SHOE_SPRITE,
             BOTTOMCLOTHES_SPRITE,
             TOPCLOTHES_SPRITE,
+#ifdef EATHENA_SUPPORT
             MISC1_SPRITE,
             MISC2_SPRITE,
+#endif
             HAIR_SPRITE,
             HAT_SPRITE,
+#ifdef EATHENA_SUPPORT
             CAPE_SPRITE,
             GLOVES_SPRITE,
+#endif
             WEAPON_SPRITE,
+#ifdef EATHENA_SUPPORT
             SHIELD_SPRITE,
+#endif
             VECTOREND_SPRITE
         };
 
-        enum TargetCursorSize {
+        enum TargetCursorSize
+        {
             TC_SMALL = 0,
             TC_MEDIUM,
             TC_LARGE,
             NUM_TC
         };
 
+        enum Speech
+        {
+            NO_SPEECH = 0,
+            TEXT_OVERHEAD,
+            NO_NAME_IN_BUBBLE,
+            NAME_IN_BUBBLE
+        };
+
+        enum AttackType
+        {
+            HIT = 0x00,
+            CRITICAL = 0x0a,
+            MULTI = 0x08,
+            REFLECT = 0x04,
+            FLEE = 0x0b
+        };
+
         /**
          * Directions, to be used as bitmask values
          */
         enum { DOWN = 1, LEFT = 2, UP = 4, RIGHT = 8 };
 
-        Uint16 mJob;            /**< Job (player job, npc, monster, ) */
-        Uint16 mX, mY;          /**< Tile coordinates */
-        Uint8 mAction;          /**< Action the being is performing */
-        Uint8 mFrame;
-        Uint16 mWalkTime;
-        Uint8 mEmotion;         /**< Currently showing emotion */
-        Uint8 mEmotionTime;     /**< Time until emotion disappears */
+#ifdef EATHENA_SUPPORT
+        Uint16 mX, mY;        /**< Tile coordinates */
+        int mFrame;
+        int mWalkTime;
+#endif
+        int mEmotion;         /**< Currently showing emotion */
+        int mEmotionTime;     /**< Time until emotion disappears */
+        int mSpeechTime;
 
-        Uint16 mAttackSpeed;          /**< Attack speed */
+        int mAttackSpeed;     /**< Attack speed */
+        Action mAction;       /**< Action the being is performing */
+        Uint16 mJob;          /**< Job (player job, npc, monster, creature ) */
 
         /**
          * Constructor.
+         *
+         * @param id   a unique being id
+         * @param job  partly determines the type of the being
+         * @param map  the map the being is on
          */
         Being(int id, int job, Map *map);
 
-        /**
-         * Destructor.
-         */
         virtual ~Being();
 
         /**
@@ -133,7 +180,26 @@ class Being : public Sprite
         /**
          * Sets a new destination for this being to walk to.
          */
+#ifdef EATHENA_SUPPORT
         virtual void setDestination(Uint16 destX, Uint16 destY);
+#else
+        void setDestination(int x, int y);
+
+        /**
+         * Returns the destination for this being.
+         */
+        const Vector &getDestination() const { return mDest; }
+
+        /**
+         * Adjusts course to expected start point.
+         */
+        void adjustCourse(int srcX, int srcY);
+
+        /**
+         * Adjusts course to expected start and end points.
+         */
+        void adjustCourse(int srcX, int srcY, int destX, int destY);
+#endif
 
         /**
          * Puts a "speech balloon" above this being for the specified amount
@@ -142,22 +208,29 @@ class Being : public Sprite
          * @param text The text that should appear.
          * @param time The amount of time the text should stay in milliseconds.
          */
-        void setSpeech(const std::string &text, Uint32 time);
+        void setSpeech(const std::string &text, int time = 500);
 
         /**
          * Puts a damage bubble above this being.
          *
-         * @param amount The amount of damage.
+         * @param attacker the attacking being
+         * @param damage the amount of damage recieved (0 means miss)
+         * @param type the attack type
          */
-        virtual void takeDamage(int amount);
+        virtual void takeDamage(Being *attacker, int damage, AttackType type);
 
         /**
          * Handles an attack of another being by this being.
          *
-         * @param victim The attacked being.
-         * @param damage The amount of damage dealt (0 means miss).
+         * @param victim the victim being
+         * @param damage the amount of damage dealt (0 means miss)
+         * @param type the attack type
          */
-        virtual void handleAttack(Being *victim, int damage);
+#ifdef TMWSERV_SUPPORT
+        virtual void handleAttack();
+#else
+        virtual void handleAttack(Being *victim, int damage, AttackType type);
+#endif
 
         /**
          * Returns the name of the being.
@@ -176,14 +249,17 @@ class Being : public Sprite
         /**
          * Gets the hair color for this being.
          */
-        int getHairColor() const
-        { return mHairColor; }
+        int getHairColor() const { return mHairColor; }
 
         /**
          * Gets the hair style for this being.
          */
-        int getHairStyle() const
-        { return mHairStyle; }
+        int getHairStyle() const { return mHairStyle; }
+
+        /**
+         * Get the number of hairstyles implemented
+         */
+        static int getNumOfHairstyles() { return mNumberOfHairstyles; }
 
         /**
          * Sets the hair style and color for this being.
@@ -193,28 +269,33 @@ class Being : public Sprite
         /**
          * Sets visible equipments for this being.
          */
-        virtual void setSprite(int slot, int id, std::string color = "");
+        virtual void setSprite(int slot, int id,
+                               const std::string &color = "");
 
         /**
          * Sets the gender of this being.
          */
         virtual void setGender(Gender gender) { mGender = gender; }
 
-        /**
-         * Gets the gender of this being.
-         */
         Gender getGender() const { return mGender; }
 
+#ifdef EATHENA_SUPPORT
         /**
          * Makes this being take the next step of his path.
          */
         virtual void nextStep();
+#endif
 
         /**
          * Performs being logic.
          */
         virtual void logic();
 
+        /**
+         * Draws the speech text above the being.
+         */
+        void drawSpeech(int offsetX, int offsetY);
+
         /**
          * Draws the emotion picture above the being.
          */
@@ -226,24 +307,18 @@ class Being : public Sprite
         virtual Type getType() const;
 
         /**
-         * Gets the walk speed.
+         * Sets the walk speed (in pixels per second).
          */
-        Uint16 getWalkSpeed() const { return mWalkSpeed; }
+        void setWalkSpeed(int speed) { mWalkSpeed = speed; }
 
-        /**
-         * Sets the walk speed.
-         */
-        void setWalkSpeed(Uint16 speed) { mWalkSpeed = speed; }
-
-        /**
-         * Gets the sprite id.
-         */
-        Uint32 getId() const { return mId; }
+        int getWalkSpeed() const { return mWalkSpeed; }
 
         /**
          * Sets the sprite id.
          */
-        void setId(Uint32 id) { mId = id; }
+        void setId(int id) { mId = id; }
+
+        int getId() const { return mId; }
 
         /**
          * Sets the map the being is on
@@ -253,7 +328,12 @@ class Being : public Sprite
         /**
          * Sets the current action.
          */
-        virtual void setAction(Uint8 action);
+        virtual void setAction(Action action, int attackType = 0);
+
+        /**
+         * Returns whether this being is still alive.
+         */
+        bool isAlive() const { return mAction != DEAD; }
 
         /**
          * Returns the current direction.
@@ -265,6 +345,23 @@ class Being : public Sprite
          */
         void setDirection(Uint8 direction);
 
+#ifdef EATHENA_SUPPORT
+        /**
+         * Returns the walk time.
+         */
+        int getWalkTime() const { return mWalkTime; }
+#endif
+
+        /**
+         * Returns the direction the being is facing.
+         */
+#ifdef TMWSERV_SUPPORT
+        SpriteDirection getSpriteDirection() const
+        { return SpriteDirection(mSpriteDirection); }
+#else
+        SpriteDirection getSpriteDirection() const;
+#endif
+
         /**
          * Draws this being to the given graphics context.
          *
@@ -273,17 +370,18 @@ class Being : public Sprite
         virtual void draw(Graphics *graphics, int offsetX, int offsetY) const;
 
         /**
-         * Returns the pixel X coordinate.
+         * Returns the X coordinate in pixels.
          */
         int getPixelX() const { return mPx; }
 
         /**
-         * Returns the pixel Y coordinate.
+         * Returns the Y coordinate in pixels.
          *
          * @see Sprite::getPixelY()
          */
         int getPixelY() const { return mPy; }
 
+#ifdef EATHENA_SUPPORT
         /**
          * Get the current X pixel offset.
          */
@@ -295,14 +393,36 @@ class Being : public Sprite
          */
         int getYOffset() const
         { return getOffset(UP, DOWN); }
+#endif
 
         /**
-         * Returns the horizontal size of the current base sprite of the being
+         * Sets the position of this being.
+         */
+        void setPosition(const Vector &pos);
+
+        /**
+         * Overloaded method provided for convenience.
+         *
+         * @see setPosition(const Vector &pos)
+         */
+        void setPosition(float x, float y, float z = 0.0f)
+        {
+            setPosition(Vector(x, y, z));
+        }
+
+        /**
+         * Returns the position of this being.
+         */
+        const Vector &getPosition() const { return mPos; }
+
+
+        /**
+         * Returns the horizontal size of the current base sprite of the being.
          */
         virtual int getWidth() const;
 
         /**
-         * Returns the vertical size of the current base sprite of the being
+         * Returns the vertical size of the current base sprite of the being.
          */
         virtual int getHeight() const;
 
@@ -317,6 +437,28 @@ class Being : public Sprite
          */
         void controlParticle(Particle *particle);
 
+        /**
+         * Gets the way the object is blocked by other objects.
+         */
+        virtual unsigned char getWalkMask() const
+        { return 0x00; } //can walk through everything
+
+        /**
+         * Returns the path this being is following. An empty path is returned
+         * when this being isn't following any path currently.
+         */
+        const Path &getPath() const { return mPath; }
+
+        /**
+         * Sets the target animation for this being.
+         */
+        void setTargetAnimation(SimpleAnimation* animation);
+
+        /**
+         * Untargets the being
+         */
+        void untarget() { mUsedTargetCursor = NULL; }
+
         void setEmote(Uint8 emotion, Uint8 emote_time)
         {
             mEmotion = emotion;
@@ -356,14 +498,14 @@ class Being : public Sprite
             internalTriggerEffect(effectId, false, true);
         }
 
-        const std::auto_ptr<Equipment> mEquipment;
+        static int getHairStyleCount();
 
+        virtual AnimatedSprite *getSprite(int index) const
+        { return mSprites[index]; }
 
-        static int getHairColorsNr();
+        static void load();
 
-        static int getHairStylesNr();
-
-        static std::string getHairColor(int index);
+        void optionChanged(const std::string &value) {}
 
     protected:
         /**
@@ -372,14 +514,15 @@ class Being : public Sprite
         void setPath(const Path &path);
 
         /**
-         * Let the sub-classes react to a replacement
+         * Let the sub-classes react to a replacement.
          */
         virtual void updateCoords() {}
 
         /**
-         * Returns the sprite direction of this being.
+         * Gets the way the object blocks pathfinding for other objects
          */
-        SpriteDirection getSpriteDirection() const;
+        virtual Map::BlockType getBlockType() const
+        { return Map::BLOCKTYPE_NONE; }
 
         /**
          * Trigger visual effect, with components
@@ -391,7 +534,7 @@ class Being : public Sprite
         void internalTriggerEffect(int effectId, bool sfx, bool gfx);
 
         /**
-         * Notify self that the stun mode has been updated.  Invoked by
+         * Notify self that the stun mode has been updated. Invoked by
          * setStunMode if something changed.
          */
         virtual void updateStunMode(int oldMode, int newMode);
@@ -410,25 +553,32 @@ class Being : public Sprite
          */
         virtual void handleStatusEffect(StatusEffect *effect, int effectId);
 
-        Uint32 mId;                     /**< Unique sprite id */
-        Uint16 mWalkSpeed;              /**< Walking speed */
+        int mId;                        /**< Unique sprite id */
         Uint8 mDirection;               /**< Facing direction */
+#ifdef TMWSERV_SUPPORT
+        Uint8 mSpriteDirection;         /**< Facing direction */
+#endif
         Map *mMap;                      /**< Map on which this being resides */
         std::string mName;              /**< Name of character */
         SpriteIterator mSpriteIterator;
+        bool mParticleEffects;          /**< Whether to display particles or not */
 
         /** Engine-related infos about weapon. */
-        const ItemInfo* mEquippedWeapon;
+        const ItemInfo *mEquippedWeapon;
+
+        static int mNumberOfHairstyles;          /** Number of hair styles in use */
 
         Path mPath;
-        Text *mSpeech;
-        Uint16 mHairStyle, mHairColor;
+        std::string mSpeech;
+        Text *mText;
+        int mHairStyle;
+        int mHairColor;
         Gender mGender;
-        Uint32 mSpeechTime;
-        Sint32 mPx, mPy;                /**< Pixel coordinates */
         Uint16 mStunMode;               /**< Stun mode; zero if not stunned */
         std::set<int> mStatusEffects;   /**< set of active status effects */
 
+        const gcn::Color *mNameColor;
+
         std::vector<AnimatedSprite*> mSprites;
         std::vector<int> mSpriteIDs;
         std::vector<std::string> mSpriteColors;
@@ -437,15 +587,28 @@ class Being : public Sprite
         ParticleList mChildParticleEffects;
 
     private:
+#ifdef EATHENA_SUPPORT
         /**
          * Calculates the offset in the given directions.
          * If walking in direction 'neg' the value is negated.
          */
         int getOffset(char pos, char neg) const;
+#endif
 
-        static int instances;           /**< Number of Being instances */
-        static ImageSet *emotionSet;    /**< Emoticons used by beings */
-        bool mMustResetParticles;	/**< Reset particle status effects on next redraw? */
+        /** Reset particle status effects on next redraw? */
+        bool mMustResetParticles;
+
+        /** Speech Bubble components */
+        SpeechBubble *mSpeechBubble;
+
+        int mWalkSpeed;                 /**< Walking speed (pixels/sec) */
+
+        Vector mPos;
+        Vector mDest;
+        int mPx, mPy;                   /**< Position in pixels */
+
+        /** Target cursor being used */
+        SimpleAnimation* mUsedTargetCursor;
 };
 
 #endif
