@@ -22,8 +22,7 @@
 #ifndef CONFIGLISTENER_H
 #define CONFIGLISTENER_H
 
-#include <iosfwd>
-
+#include <string>
 
 /**
  * The listener interface for receiving notifications about changes to
@@ -37,7 +36,7 @@ class ConfigListener
         /**
          * Destructor.
          */
-        virtual ~ConfigListener() {};
+        virtual ~ConfigListener() {}
 
         /**
          * Called when an option changed. The config listener will have to be
