@@ -19,44 +19,33 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "engine.h"
-
-#include <list>
-
-#include "being.h"
 #include "beingmanager.h"
-#include "configuration.h"
+#include "engine.h"
 #include "flooritemmanager.h"
 #include "game.h"
-#include "graphics.h"
 #include "localplayer.h"
 #include "log.h"
-#include "main.h"
 #include "map.h"
 #include "particle.h"
 #include "sound.h"
 
 #include "gui/gui.h"
 #include "gui/minimap.h"
+#include "gui/okdialog.h"
 #include "gui/viewport.h"
 
-#include "net/messageout.h"
-#include "net/protocol.h"
+#include "net/maphandler.h"
+#include "net/net.h"
 
 #include "resources/mapreader.h"
 #include "resources/monsterdb.h"
 #include "resources/resourcemanager.h"
 
-#include "utils/dtor.h"
-#include "utils/tostring.h"
+#include "utils/gettext.h"
+#include "utils/stringutils.h"
 
-extern Minimap *minimap;
-
-char itemCurrenyQ[10] = "0";
-
-Engine::Engine(Network *network):
-    mCurrentMap(NULL),
-    mNetwork(network)
+Engine::Engine():
+    mCurrentMap(0)
 {
 }
 
@@ -65,12 +54,16 @@ Engine::~Engine()
     delete mCurrentMap;
 }
 
-void Engine::changeMap(const std::string &mapPath)
+bool Engine::changeMap(const std::string &mapPath)
 {
     // Clean up floor items, beings and particles
     floorItemManager->clear();
     beingManager->clear();
 
+    // Close the popup menu on map change so that invalid options can't be
+    // executed.
+    viewport->closePopupMenu();
+
     // Unset the map of the player so that its particles are cleared before
     // being deleted in the next step
     if (player_node)
@@ -78,67 +71,50 @@ void Engine::changeMap(const std::string &mapPath)
 
     particleEngine->clear();
 
+    mMapName = mapPath;
+
     // Store full map path in global var
-    map_path = "maps/" + mapPath.substr(0, mapPath.rfind(".")) + ".tmx";
+    map_path = "maps/" + mapPath + ".tmx";
     ResourceManager *resman = ResourceManager::getInstance();
     if (!resman->exists(map_path))
-    {
         map_path += ".gz";
-    }
 
     // Attempt to load the new map
     Map *newMap = MapReader::readMap(map_path);
 
-    if (!newMap) {
-        logger->error("Could not find map file");
+    if (!newMap)
+    {
+        logger->log("Error while loading %s", map_path.c_str());
+        new OkDialog(_("Could not load map"),
+                     strprintf(_("Error while loading %s"), map_path.c_str()));
     }
 
     // Notify the minimap and beingManager about the map change
-    Image *mapImage = NULL;
-    if (newMap->hasProperty("minimap"))
-    {
-        mapImage = resman->getImage(newMap->getProperty("minimap"));
-    }
-    if (newMap->hasProperty("name"))
-    {
-        minimap->setCaption(newMap->getProperty("name"));
-    } else {
-        minimap->setCaption("Map");
-    }
-    minimap->setMapImage(mapImage);
+    minimap->setMap(newMap);
     beingManager->setMap(newMap);
     particleEngine->setMap(newMap);
     viewport->setMap(newMap);
 
     // Initialize map-based particle effects
-    newMap->initializeParticleEffects(particleEngine);
+    if (newMap)
+        newMap->initializeParticleEffects(particleEngine);
 
     // Start playing new music file when necessary
-    std::string oldMusic = "";
-
-    if (mCurrentMap) {
-        oldMusic = mCurrentMap->getProperty("music");
-        delete mCurrentMap;
-    }
-
-    std::string newMusic = newMap->getProperty("music");
-
-    if (newMusic != oldMusic) {
-        sound.playMusic(newMusic, -1);
-    }
+    std::string oldMusic = mCurrentMap ? mCurrentMap->getMusicFile() : "";
+    std::string newMusic = newMap ? newMap->getMusicFile() : "";
+    if (newMusic != oldMusic)
+        sound.playMusic(newMusic);
 
+    delete mCurrentMap;
     mCurrentMap = newMap;
-    mMapName = mapPath;
 
-    // Send "map loaded"
-    MessageOut outMsg(mNetwork);
-    outMsg.writeInt16(CMSG_MAP_LOADED);
+    Net::getMapHandler()->mapLoaded(mapPath);
+    return true;
 }
 
 void Engine::logic()
 {
     beingManager->logic();
     particleEngine->update();
-    mCurrentMap->update();
     gui->logic();
 }
