@@ -22,11 +22,9 @@
 #ifndef _ENGINE_H
 #define _ENGINE_H
 
-#include <iosfwd>
 #include <string>
 
 class Map;
-class Network;
 
 /**
  * Game engine. Actually hardly does anything anymore except keeping track of
@@ -35,14 +33,8 @@ class Network;
 class Engine
 {
     public:
-        /**
-         * Constructor.
-         */
-        Engine(Network *network);
+        Engine();
 
-        /**
-         * Destructor.
-         */
         ~Engine();
 
         /**
@@ -52,20 +44,18 @@ class Engine
 
         const std::string &getCurrentMapName() { return mMapName; }
 
-
         /**
          * Sets the currently active map.
          */
-        void changeMap(const std::string &mapName);
+        bool changeMap(const std::string &mapName);
 
         /**
-         * Performs engine logic.
+         * Performs engine logic. This method is called 100 times per second.
          */
         void logic();
 
     private:
         Map *mCurrentMap;
-        Network *mNetwork;
         std::string mMapName;
 };
 
