@@ -21,22 +21,63 @@
 
 #include "equipment.h"
 #include "item.h"
+#ifdef EATHENA_SUPPORT
 #include "inventory.h"
 #include "localplayer.h"
+#endif
 
 #include <algorithm>
 
-Equipment::Equipment():
-    mArrows(0)
+Equipment::Equipment()
+#ifdef EATHENA_SUPPORT
+    : mArrows(-1)
+#endif
 {
-    std::fill_n(mEquipment, EQUIPMENT_SIZE, 0);
+#ifdef TMWSERV_SUPPORT
+    std::fill_n(mEquipment, EQUIPMENT_SIZE, (Item*) 0);
+#else
+    std::fill_n(mEquipment, EQUIPMENT_SIZE, -1);
+#endif
 }
 
-void
-Equipment::setEquipment(int index, int inventoryIndex)
+#ifdef TMWSERV_SUPPORT
+
+Equipment::~Equipment()
+{
+    clear();
+}
+
+void Equipment::clear()
+{
+    for (int i = 0; i < EQUIPMENT_SIZE; ++i)
+        delete mEquipment[i];
+
+    std::fill_n(mEquipment, EQUIPMENT_SIZE, (Item*) 0);
+}
+
+void Equipment::setEquipment(int index, int id)
+{
+    if (mEquipment[index] && mEquipment[index]->getId() == id)
+        return;
+
+    delete mEquipment[index];
+    mEquipment[index] = (id > 0) ? new Item(id) : 0;
+}
+
+#else
+
+void Equipment::setEquipment(int index, int inventoryIndex)
 {
     mEquipment[index] = inventoryIndex;
-    Item* item = player_node->getInventory()->getItem(inventoryIndex);
+    Item *item = player_node->getInventory()->getItem(inventoryIndex);
     if (item)
-    	item->setEquipped(true);
+        item->setEquipped(true);
 }
+
+void Equipment::removeEquipment(int index)
+{
+     if (index >= 0 && index < EQUIPMENT_SIZE)
+         mEquipment[index] = -1;
+}
+
+#endif
