@@ -19,28 +19,24 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef GAME_
-#define GAME_
+#ifndef GAME_H
+#define GAME_H
 
-#include <iosfwd>
-#include <memory>
+#include "SDL.h"
 
 #include "configlistener.h"
 
-#define SPEECH_TIME 80
-#define SPEECH_MAX_TIME 100
-
-class MessageHandler;
-class Network;
-
 extern std::string map_path;
 extern volatile int fps;
 extern volatile int tick_time;
 
+class WindowMenu;
+
 class Game : public ConfigListener
 {
     public:
-        Game(Network *network);
+        Game();
+
         ~Game();
 
         void logic();
@@ -50,25 +46,18 @@ class Game : public ConfigListener
         void optionChanged(const std::string &name);
 
     private:
-        Network *mNetwork;
-
         /** Used to determine whether to draw the next frame. */
         int mDrawTime;
 
         /** The minimum frame time (used for frame limiting). */
         int mMinFrameTime;
 
-        typedef const std::auto_ptr<MessageHandler> MessageHandlerPtr;
-        MessageHandlerPtr mBeingHandler;
-        MessageHandlerPtr mBuySellHandler;
-        MessageHandlerPtr mChatHandler;
-        MessageHandlerPtr mEquipmentHandler;
-        MessageHandlerPtr mInventoryHandler;
-        MessageHandlerPtr mItemHandler;
-        MessageHandlerPtr mNpcHandler;
-        MessageHandlerPtr mPlayerHandler;
-        MessageHandlerPtr mSkillHandler;
-        MessageHandlerPtr mTradeHandler;
+        int mLastTarget;
+
+        SDL_TimerID mLogicCounterId;
+        SDL_TimerID mSecondsCounterId;
+
+        WindowMenu *mWindowMenu;
 };
 
 /**
