@@ -42,35 +42,32 @@ bool Graphics::setVideoMode(int w, int h, int bpp, bool fs, bool hwaccel)
     logger->log("Setting video mode %dx%d %s",
             w, h, fs ? "fullscreen" : "windowed");
 
+    logger->log("Bits per pixel: %d", bpp);
+
     int displayFlags = SDL_ANYFORMAT;
 
     mFullscreen = fs;
     mHWAccel = hwaccel;
 
-    if (fs) {
+    if (fs)
         displayFlags |= SDL_FULLSCREEN;
-    }
 
-    if (hwaccel) {
+    if (hwaccel)
         displayFlags |= SDL_HWSURFACE | SDL_DOUBLEBUF;
-    } else {
+    else
         displayFlags |= SDL_SWSURFACE;
-    }
 
     mScreen = SDL_SetVideoMode(w, h, bpp, displayFlags);
 
-    if (!mScreen) {
+    if (!mScreen)
         return false;
-    }
 
     char videoDriverName[64];
 
-    if (SDL_VideoDriverName(videoDriverName, 64)) {
+    if (SDL_VideoDriverName(videoDriverName, 64))
         logger->log("Using video driver: %s", videoDriverName);
-    }
-    else {
-        logger->log("Using video driver: unkown");
-    }
+    else
+        logger->log("Using video driver: unknown");
 
     const SDL_VideoInfo *vi = SDL_GetVideoInfo();
 
@@ -101,20 +98,19 @@ bool Graphics::setVideoMode(int w, int h, int bpp, bool fs, bool hwaccel)
 
 bool Graphics::setFullscreen(bool fs)
 {
-    if (mFullscreen == fs) {
+    if (mFullscreen == fs)
         return true;
-    }
 
     return setVideoMode(mScreen->w, mScreen->h,
             mScreen->format->BitsPerPixel, fs, mHWAccel);
 }
 
-int Graphics::getWidth()
+int Graphics::getWidth() const
 {
     return mScreen->w;
 }
 
-int Graphics::getHeight()
+int Graphics::getHeight() const
 {
     return mScreen->h;
 }
@@ -125,7 +121,7 @@ bool Graphics::drawImage(Image *image, int x, int y)
 }
 
 bool Graphics::drawImage(Image *image, int srcX, int srcY, int dstX, int dstY,
-        int width, int height, bool)
+                         int width, int height, bool)
 {
     // Check that preconditions for blitting are met.
     if (!mScreen || !image || !image->mImage) return false;
@@ -147,7 +143,7 @@ bool Graphics::drawImage(Image *image, int srcX, int srcY, int dstX, int dstY,
 }
 
 void Graphics::drawImage(gcn::Image const *image, int srcX, int srcY,
-               int dstX, int dstY, int width, int height)
+                         int dstX, int dstY, int width, int height)
 {
     ProxyImage const *srcImage =
         dynamic_cast< ProxyImage const * >(image);
@@ -157,32 +153,43 @@ void Graphics::drawImage(gcn::Image const *image, int srcX, int srcY,
 
 void Graphics::drawImagePattern(Image *image, int x, int y, int w, int h)
 {
-    int iw = image->getWidth();
-    int ih = image->getHeight();
-    if (iw == 0 || ih == 0) return;
+    // Check that preconditions for blitting are met.
+    if (!mScreen || !image || !image->mImage) return;
 
-    int px = 0;                       // X position on pattern plane
-    int py = 0;                       // Y position on pattern plane
+    const int iw = image->getWidth();
+    const int ih = image->getHeight();
+ 
+    if (iw == 0 || ih == 0) return;                         
 
-    while (py < h) {
-        while (px < w) {
+    for (int py = 0; py < h; py += ih)     // Y position on pattern plane
+    {
+        int dh = (py + ih >= h) ? h - py : ih;
+        int srcY = image->mBounds.y;
+        int dstY = y + py + mClipStack.top().yOffset;
+
+        for (int px = 0; px < w; px += iw) // X position on pattern plane  
+        {
             int dw = (px + iw >= w) ? w - px : iw;
-            int dh = (py + ih >= h) ? h - py : ih;
-            drawImage(image, 0, 0, x + px, y + py, dw, dh);
-            px += iw;
+            int srcX = image->mBounds.x;
+            int dstX = x + px + mClipStack.top().xOffset;
+
+            SDL_Rect dstRect;
+            SDL_Rect srcRect;
+            dstRect.x = dstX; dstRect.y = dstY;
+            srcRect.x = srcX; srcRect.y = srcY;
+            srcRect.w = dw;   srcRect.h = dh;
+
+            SDL_BlitSurface(image->mImage, &srcRect, mScreen, &dstRect);
         }
-        py += ih;
-        px = 0;
     }
 }
 
-void
-Graphics::drawImageRect(int x, int y, int w, int h,
-                        Image *topLeft, Image *topRight,
-                        Image *bottomLeft, Image *bottomRight,
-                        Image *top, Image *right,
-                        Image *bottom, Image *left,
-                        Image *center)
+void Graphics::drawImageRect(int x, int y, int w, int h,
+                             Image *topLeft, Image *topRight,
+                             Image *bottomLeft, Image *bottomRight,
+                             Image *top, Image *right,
+                             Image *bottom, Image *left,
+                             Image *center)
 {
     pushClipArea(gcn::Rectangle(x, y, w, h));
 
@@ -220,9 +227,8 @@ Graphics::drawImageRect(int x, int y, int w, int h,
     popClipArea();
 }
 
-void
-Graphics::drawImageRect(int x, int y, int w, int h,
-                        const ImageRect &imgRect)
+void Graphics::drawImageRect(int x, int y, int w, int h,
+                             const ImageRect &imgRect)
 {
     drawImageRect(x, y, w, h,
             imgRect.grid[0], imgRect.grid[2], imgRect.grid[6], imgRect.grid[8],
@@ -235,7 +241,7 @@ void Graphics::updateScreen()
     SDL_Flip(mScreen);
 }
 
-SDL_Surface* Graphics::getScreenshot()
+SDL_Surface *Graphics::getScreenshot()
 {
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
     int rmask = 0xff000000;
