@@ -19,8 +19,8 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _GRAPHICS_H
-#define _GRAPHICS_H
+#ifndef GRAPHICS_H
+#define GRAPHICS_H
 
 #include <guichan/sdl/sdlgraphics.hpp>
 
@@ -46,14 +46,29 @@ struct SDL_Surface;
  * Sections 0, 2, 6 and 8 will remain as is. 1, 3, 4, 5 and 7 will be
  * repeated to fit the size of the widget.
  */
-struct ImageRect {
+struct ImageRect
+{
+    enum ImagePosition
+    {
+        UPPER_LEFT = 0,
+        UPPER_CENTER = 1,
+        UPPER_RIGHT = 2,
+        LEFT = 3,
+        CENTER = 4,
+        RIGHT = 5,
+        LOWER_LEFT = 6,
+        LOWER_CENTER = 7,
+        LOWER_RIGHT = 8
+    };
+
     Image *grid[9];
 };
 
 /**
  * A central point of control for graphics.
  */
-class Graphics : public gcn::SDLGraphics {
+class Graphics : public gcn::SDLGraphics
+{
     public:
         /**
          * Constructor.
@@ -95,17 +110,15 @@ class Graphics : public gcn::SDLGraphics {
          * @return <code>true</code> if the image was blitted properly
          *         <code>false</code> otherwise.
          */
-        virtual bool
-        drawImage(Image *image,
-                  int srcX, int srcY,
-                  int dstX, int dstY,
-                  int width, int height,
-                  bool useColor = false);
+        virtual bool drawImage(Image *image,
+                               int srcX, int srcY,
+                               int dstX, int dstY,
+                               int width, int height,
+                               bool useColor = false);
 
-        virtual void
-        drawImagePattern(Image *image,
-                         int x, int y,
-                         int w, int h);
+        virtual void drawImagePattern(Image *image,
+                                      int x, int y,
+                                      int w, int h);
 
         /**
          * Draws a rectangle using images. 4 corner images, 4 side images and 1
@@ -136,21 +149,23 @@ class Graphics : public gcn::SDLGraphics {
         /**
          * Returns the width of the screen.
          */
-        int getWidth();
+        int getWidth() const;
 
         /**
          * Returns the height of the screen.
          */
-        int getHeight();
+        int getHeight() const;
 
         /**
          * Takes a screenshot and returns it as SDL surface.
          */
-        virtual SDL_Surface* getScreenshot();
+        virtual SDL_Surface *getScreenshot();
 
     protected:
         SDL_Surface *mScreen;
         bool mFullscreen, mHWAccel;
 };
 
+extern Graphics *graphics;
+
 #endif
