@@ -22,13 +22,12 @@
 #ifndef BUDDYWINDOW_H
 #define BUDDYWINDOW_H
 
+#include "gui/widgets/window.h"
+
 #include <guichan/actionlistener.hpp>
+#include <guichan/actionevent.hpp>
 
-#include "window.h"
-
-#include "../guichanfwd.h"
-
-class BuddyList;
+class Avatar;
 
 /**
  * Window showing buddy list.
@@ -48,9 +47,14 @@ class BuddyWindow : public Window, public gcn::ActionListener
          */
         void action(const gcn::ActionEvent &event);
 
+        /**
+         * Draws the window
+         */
+        void draw(gcn::Graphics *graphics);
+
+
     private:
-        BuddyList *mBuddyList;
-        gcn::ListBox *mListbox;
+        std::list<Avatar*> mBuddyList;
 };
 
 #endif /* BUDDYWINDOW_H */
