@@ -19,54 +19,63 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "buy.h"
+#include "gui/buy.h"
 
-#include <guichan/widgets/label.hpp>
+#include "gui/widgets/button.h"
+#include "gui/widgets/label.h"
+#include "gui/widgets/layout.h"
+#include "gui/widgets/scrollarea.h"
+#include "gui/widgets/slider.h"
 
-#include "button.h"
-#include "scrollarea.h"
-#include "shop.h"
-#include "shoplistbox.h"
-#include "slider.h"
+#include "gui/shop.h"
+#include "gui/shoplistbox.h"
 
-#include "widgets/layout.h"
+#include "npc.h"
+#include "shopitem.h"
+#include "units.h"
 
-#include "../npc.h"
+#include "net/net.h"
+#include "net/npchandler.h"
 
-#include "../net/messageout.h"
-#include "../net/protocol.h"
+#include "resources/iteminfo.h"
 
-#include "../utils/gettext.h"
-#include "../utils/strprintf.h"
+#include "utils/gettext.h"
+#include "utils/stringutils.h"
 
-BuyDialog::BuyDialog(Network *network):
-    Window(_("Buy")), mNetwork(network),
+BuyDialog::BuyDialog():
+    Window(_("Buy")),
     mMoney(0), mAmountItems(0), mMaxItems(0)
 {
     setWindowName("Buy");
     setResizable(true);
+    setCloseButton(true);
     setMinWidth(260);
     setMinHeight(230);
-    setDefaultSize(0, 0, 260, 230);
+    setDefaultSize(260, 230, ImageRect::CENTER);
 
     mShopItems = new ShopItems;
 
     mShopItemList = new ShopListBox(mShopItems, mShopItems);
     mScrollArea = new ScrollArea(mShopItemList);
+    mScrollArea->setHorizontalScrollPolicy(gcn::ScrollArea::SHOW_NEVER);
+
     mSlider = new Slider(1.0);
-    mQuantityLabel = new gcn::Label("0");
-    mMoneyLabel = new gcn::Label(strprintf(_("Price: %d GP / Total: %d GP"), 0, 0));
+    mQuantityLabel = new Label(strprintf("%d / %d", mAmountItems, mMaxItems));
+    mQuantityLabel->setAlignment(gcn::Graphics::CENTER);
+    mMoneyLabel = new Label(strprintf(_("Price: %s / Total: %s"),
+                                            "", ""));
+
     mIncreaseButton = new Button("+", "+", this);
     mDecreaseButton = new Button("-", "-", this);
     mBuyButton = new Button(_("Buy"), "buy", this);
     mQuitButton = new Button(_("Quit"), "quit", this);
-    mItemDescLabel = new gcn::Label(strprintf(_("Description: %s"), ""));
-    mItemEffectLabel = new gcn::Label(strprintf(_("Effect: %s"), ""));
+    mAddMaxButton = new Button(_("Max"), "max", this);
+    mItemDescLabel = new Label(strprintf(_("Description: %s"), ""));
+    mItemEffectLabel = new Label(strprintf(_("Effect: %s"), ""));
 
-    mIncreaseButton->setSize(20, 20);
-    mDecreaseButton->setSize(20, 20);
+    mDecreaseButton->adjustSize();
+    mDecreaseButton->setWidth(mIncreaseButton->getWidth());
 
-    mScrollArea->setHorizontalScrollPolicy(gcn::ScrollArea::SHOW_NEVER);
     mIncreaseButton->setEnabled(false);
     mDecreaseButton->setEnabled(false);
     mBuyButton->setEnabled(false);
@@ -76,21 +85,26 @@ BuyDialog::BuyDialog(Network *network):
     mSlider->addActionListener(this);
     mShopItemList->addSelectionListener(this);
 
-    place(0, 0, mScrollArea, 5).setPadding(3);
-    place(0, 1, mQuantityLabel, 2);
-    place(2, 1, mSlider, 3);
-    place(0, 2, mMoneyLabel, 5);
-    place(0, 3, mItemEffectLabel, 5);
-    place(0, 4, mItemDescLabel, 5);
+    ContainerPlacer place;
+    place = getPlacer(0, 0);
+
+    place(0, 0, mScrollArea, 8, 5).setPadding(3);
     place(0, 5, mDecreaseButton);
-    place(1, 5, mIncreaseButton);
-    place(3, 5, mBuyButton);
-    place(4, 5, mQuitButton);
+    place(1, 5, mSlider, 3);
+    place(4, 5, mIncreaseButton);
+    place(5, 5, mQuantityLabel, 2);
+    place(7, 5, mAddMaxButton);
+    place(0, 6, mMoneyLabel, 8);
+    place(0, 7, mItemEffectLabel, 8);
+    place(0, 8, mItemDescLabel, 8);
+    place(6, 9, mBuyButton);
+    place(7, 9, mQuitButton);
+
     Layout &layout = getLayout();
     layout.setRowHeight(0, Layout::AUTO_SET);
 
+    center();
     loadWindowState();
-    setLocationRelativeTo(getParent());
 }
 
 BuyDialog::~BuyDialog()
@@ -118,23 +132,22 @@ void BuyDialog::reset()
     setMoney(0);
 }
 
-void BuyDialog::addItem(short id, int price)
+void BuyDialog::addItem(int id, int amount, int price)
 {
-    mShopItems->addItem(id, price);
+    mShopItems->addItem(id, amount, price);
     mShopItemList->adjustSize();
 }
 
 void BuyDialog::action(const gcn::ActionEvent &event)
 {
-    int selectedItem = mShopItemList->getSelected();
-
     if (event.getId() == "quit")
     {
-        setVisible(false);
-        current_npc = 0;
+        close();
         return;
     }
 
+    int selectedItem = mShopItemList->getSelected();
+
     // The following actions require a valid selection
     if (selectedItem < 0 ||
             selectedItem >= (int) mShopItems->getNumberOfElements())
@@ -159,17 +172,21 @@ void BuyDialog::action(const gcn::ActionEvent &event)
         mSlider->setValue(mAmountItems);
         updateButtonsAndLabels();
     }
+    else if (event.getId() == "max")
+    {
+        mAmountItems = mMaxItems;
+        mSlider->setValue(mAmountItems);
+        updateButtonsAndLabels();
+    }
     // TODO: Actually we'd have a bug elsewhere if this check for the number
     // of items to be bought ever fails, Bertram removed the assertions, is
     // there a better way to ensure this fails in an _obvious_ way in C++?
     else if (event.getId() == "buy" && mAmountItems > 0 &&
                 mAmountItems <= mMaxItems)
     {
-        MessageOut outMsg(mNetwork);
-        outMsg.writeInt16(CMSG_NPC_BUY_REQUEST);
-        outMsg.writeInt16(8);
-        outMsg.writeInt16(mAmountItems);
-        outMsg.writeInt16(mShopItems->at(selectedItem)->getId());
+        Net::getNpcHandler()->buyItem(current_npc,
+                                      mShopItems->at(selectedItem)->getId(),
+                                      mAmountItems);
 
         // Update money and adjust the max number of items that can be bought
         mMaxItems -= mAmountItems;
@@ -236,5 +253,28 @@ void BuyDialog::updateButtonsAndLabels()
     // Update quantity and money labels
     mQuantityLabel->setCaption(strprintf("%d / %d", mAmountItems, mMaxItems));
     mMoneyLabel->setCaption
-        (strprintf(_("Price: %d GP / Total: %d GP"), price, mMoney - price));
+        (strprintf(_("Price: %s / Total: %s"),
+                    Units::formatCurrency(price).c_str(),
+                    Units::formatCurrency(mMoney - price).c_str()));
+}
+
+void BuyDialog::logic()
+{
+    Window::logic();
+
+    if (!current_npc) setVisible(false);
+}
+
+void BuyDialog::setVisible(bool visible)
+{
+    Window::setVisible(visible);
+
+    if (visible)
+        mShopItemList->requestFocus();
+}
+
+void BuyDialog::close()
+{
+    setVisible(false);
+    current_npc = 0;
 }
