@@ -22,14 +22,13 @@
 #ifndef BUY_H
 #define BUY_H
 
+#include "gui/widgets/window.h"
+
+#include "guichanfwd.h"
+
 #include <guichan/actionlistener.hpp>
 #include <guichan/selectionlistener.hpp>
 
-#include "window.h"
-
-#include "../guichanfwd.h"
-
-class Network;
 class ShopItems;
 class ShopListBox;
 class ListBox;
@@ -40,7 +39,7 @@ class ListBox;
  * \ingroup Interface
  */
 class BuyDialog : public Window, public gcn::ActionListener,
-    gcn::SelectionListener
+                  public gcn::SelectionListener
 {
     public:
         /**
@@ -48,7 +47,7 @@ class BuyDialog : public Window, public gcn::ActionListener,
          *
          * @see Window::Window
          */
-        BuyDialog(Network *network);
+        BuyDialog();
 
         /**
          * Destructor
@@ -68,7 +67,7 @@ class BuyDialog : public Window, public gcn::ActionListener,
         /**
          * Adds an item to the shop inventory.
          */
-        void addItem(short id, int price);
+        void addItem(int id, int amount, int price);
 
         /**
          * Called when receiving actions from the widgets.
@@ -95,10 +94,25 @@ class BuyDialog : public Window, public gcn::ActionListener,
          */
         void updateButtonsAndLabels();
 
+        /**
+         * Check for current NPC
+         */
+        void logic();
+
+        /**
+         * Sets the visibility of this window.
+         */
+        void setVisible(bool visible);
+
+        /**
+         * Closes the Buy Window, as well as resetting the current npc.
+         */
+        void close();
+
     private:
-        Network *mNetwork;
         gcn::Button *mBuyButton;
         gcn::Button *mQuitButton;
+        gcn::Button *mAddMaxButton;
         gcn::Button *mIncreaseButton;
         gcn::Button *mDecreaseButton;
         ShopListBox *mShopItemList;
@@ -116,4 +130,6 @@ class BuyDialog : public Window, public gcn::ActionListener,
         int mMaxItems;
 };
 
+extern BuyDialog *buyDialog;
+
 #endif
