@@ -21,16 +21,21 @@
 
 #include "buysell.h"
 
-#include "button.h"
+#include "npc.h"
 
-#include "../npc.h"
+#include "gui/widgets/button.h"
 
-#include "../utils/gettext.h"
+#include "net/net.h"
+#include "net/npchandler.h"
+
+#include "utils/gettext.h"
 
 BuySellDialog::BuySellDialog():
-    Window(_("Shop"))
+    Window(_("Shop")),
+    mBuyButton(0)
 {
-    Button *buyButton = 0;
+    setWindowName("BuySell");
+
     static const char *buttonNames[] = {
         N_("Buy"), N_("Sell"), N_("Cancel"), 0
     };
@@ -39,27 +44,54 @@ BuySellDialog::BuySellDialog():
     for (const char **curBtn = buttonNames; *curBtn; curBtn++)
     {
         Button *btn = new Button(gettext(*curBtn), *curBtn, this);
-        if (!buyButton) buyButton = btn; // For focus request
+        if (!mBuyButton)
+            mBuyButton = btn; // For focus request
         btn->setPosition(x, y);
         add(btn);
         x += btn->getWidth() + 10;
     }
-    buyButton->requestFocus();
+    mBuyButton->requestFocus();
 
-    setContentSize(x, 2 * y + buyButton->getHeight());
-    setLocationRelativeTo(getParent());
+    setContentSize(x, 2 * y + mBuyButton->getHeight());
 
-    requestFocus();
+    center();
+    setDefaultSize();
+    loadWindowState();
+}
+
+void BuySellDialog::logic()
+{
+    Window::logic();
+
+    if (isVisible() && !current_npc)
+        setVisible(false);
+}
+
+void BuySellDialog::setVisible(bool visible)
+{
+    Window::setVisible(visible);
+
+    if (visible)
+        mBuyButton->requestFocus();
 }
 
 void BuySellDialog::action(const gcn::ActionEvent &event)
 {
-    if (event.getId() == "Buy") {
-        current_npc->buy();
-    } else if (event.getId() == "Sell") {
-        current_npc->sell();
-    } else if (event.getId() == "Cancel") {
-        current_npc = 0;
-    }
     setVisible(false);
+
+    NPC::isTalking = false;
+
+    if (event.getId() == "Buy")
+    {
+        Net::getNpcHandler()->buy(current_npc);
+    }
+    else if (event.getId() == "Sell")
+    {
+        Net::getNpcHandler()->sell(current_npc);
+    }
+    else if (event.getId() == "Cancel")
+    {
+        current_npc = 0;
+        return;
+    }
 }
