@@ -22,9 +22,9 @@
 #ifndef BUYSELL_H
 #define BUYSELL_H
 
-#include <guichan/actionlistener.hpp>
+#include "gui/widgets/window.h"
 
-#include "window.h"
+#include <guichan/actionlistener.hpp>
 
 /**
  * A dialog to choose between buying or selling at a shop.
@@ -42,10 +42,22 @@ class BuySellDialog : public Window, public gcn::ActionListener
          */
         BuySellDialog();
 
+        /**
+         * Check for current NPC
+         */
+        void logic();
+
+        void setVisible(bool visible);
+
         /**
          * Called when receiving actions from the widgets.
          */
         void action(const gcn::ActionEvent &event);
+
+    private:
+        gcn::Button *mBuyButton;
 };
 
+extern BuySellDialog *buySellDialog;
+
 #endif
