@@ -21,32 +21,23 @@
 
 #include "connection.h"
 
-#include <guichan/actionlistener.hpp>
+#include "gui/widgets/button.h"
+#include "gui/widgets/label.h"
+#include "gui/widgets/progressbar.h"
 
-#include <guichan/widgets/label.hpp>
+#include "main.h"
+#include "log.h"
 
-#include "button.h"
-#include "progressbar.h"
+#include "utils/gettext.h"
 
-#include "../main.h"
-
-#include "../utils/gettext.h"
-
-namespace {
-    struct ConnectionActionListener : public gcn::ActionListener
-    {
-        void action(const gcn::ActionEvent &event) { state = EXIT_STATE; }
-    } listener;
-}
-
-ConnectionDialog::ConnectionDialog():
-    Window("Info"), mProgress(0)
+ConnectionDialog::ConnectionDialog(State previousState):
+    Window("Info"), mProgress(0), mPreviousState(previousState)
 {
     setContentSize(200, 100);
 
-    Button *cancelButton = new Button(_("Cancel"), "cancelButton", &listener);
-    mProgressBar = new ProgressBar(0.0, 200 - 10, 20, 128, 128, 128);
-    gcn::Label *label = new gcn::Label(_("Connecting..."));
+    Button *cancelButton = new Button(_("Cancel"), "cancelButton", this);
+    mProgressBar = new ProgressBar(0.0, 200 - 10, 20, gcn::Color(128, 128, 128));
+    gcn::Label *label = new Label(_("Connecting..."));
 
     cancelButton->setPosition(5, 100 - 5 - cancelButton->getHeight());
     mProgressBar->setPosition(5, cancelButton->getY() - 25);
@@ -56,17 +47,23 @@ ConnectionDialog::ConnectionDialog():
     add(cancelButton);
     add(mProgressBar);
 
-    setLocationRelativeTo(getParent());
+    center();
     setVisible(true);
 }
 
+void ConnectionDialog::action(const gcn::ActionEvent &)
+{
+    logger->log("Cancel pressed");
+    state = mPreviousState;
+}
+
 void ConnectionDialog::logic()
 {
     mProgress += 0.005f;
+
     if (mProgress > 1.0f)
-    {
         mProgress = 0.0f;
-    }
+
     mProgressBar->setProgress(mProgress);
     Window::logic();
 }
