@@ -22,7 +22,11 @@
 #ifndef CONNECTION_H
 #define CONNECTION_H
 
-#include "window.h"
+#include "gui/widgets/window.h"
+
+#include "main.h"
+
+#include <guichan/actionlistener.hpp>
 
 class ProgressBar;
 
@@ -31,7 +35,7 @@ class ProgressBar;
  *
  * \ingroup Interface
  */
-class ConnectionDialog : public Window
+class ConnectionDialog : public Window, gcn::ActionListener
 {
     public:
         /**
@@ -39,13 +43,20 @@ class ConnectionDialog : public Window
          *
          * @see Window::Window
          */
-        ConnectionDialog();
+        ConnectionDialog(State previousState);
+
+        /**
+         * Called when the user presses Cancel. Restores the global state to
+         * the previous one.
+         */
+        void action(const gcn::ActionEvent &);
 
         void logic();
 
     private:
         ProgressBar *mProgressBar;
         float mProgress;
+        State mPreviousState;
 };
 
 #endif
