@@ -19,24 +19,19 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "debugwindow.h"
+#include "gui/debugwindow.h"
 
-#include <SDL_mouse.h>
+#include "gui/viewport.h"
 
-#include <guichan/widgets/label.hpp>
+#include "gui/widgets/label.h"
+#include "gui/widgets/layout.h"
 
-#include "button.h"
-#include "gui.h"
-#include "viewport.h"
+#include "engine.h"
+#include "game.h"
+#include "particle.h"
+#include "map.h"
 
-#include "widgets/layout.h"
-
-#include "../engine.h"
-#include "../game.h"
-#include "../particle.h"
-#include "../map.h"
-
-#include "../utils/tostring.h"
+#include "utils/stringutils.h"
 
 DebugWindow::DebugWindow():
     Window("Debug")
@@ -45,40 +40,39 @@ DebugWindow::DebugWindow():
 
     setResizable(true);
     setCloseButton(true);
-    setDefaultSize(0, 0, 400, 60);
-    loadWindowState();
+    setSaveVisible(true);
+    setDefaultSize(400, 100, ImageRect::CENTER);
 
-    mFPSLabel = new gcn::Label("0 FPS");
-    mMusicFileLabel = new gcn::Label("Music: ");
-    mMapLabel = new gcn::Label("Map: ");
-    mMiniMapLabel = new gcn::Label("Mini-Map: ");
-    mTileMouseLabel = new gcn::Label("Mouse: 0, 0");
-    mParticleCountLabel = new gcn::Label("Particle count: 0");
+    mFPSLabel = new Label("0 FPS");
+    mMusicFileLabel = new Label("Music: ");
+    mMapLabel = new Label("Map: ");
+    mMiniMapLabel = new Label("Mini-Map: ");
+    mTileMouseLabel = new Label("Mouse: 0, 0");
+    mParticleCountLabel = new Label("Particle count: 0");
 
-    place(0, 0, mFPSLabel);
+    place(0, 0, mFPSLabel, 3);
     place(3, 0, mTileMouseLabel);
-    place(0, 1, mMusicFileLabel, 2);
+    place(0, 1, mMusicFileLabel, 3);
     place(3, 1, mParticleCountLabel);
-    place(0, 2, mMapLabel, 2);
-    place(0, 3, mMiniMapLabel, 2);
+    place(0, 2, mMapLabel, 4);
+    place(0, 3, mMiniMapLabel, 4);
 
-    reflowLayout(375, 0);
+    loadWindowState();
 }
 
 void DebugWindow::logic()
 {
+    if (!isVisible())
+        return;
+
     // Get the current mouse position
-    int mouseX, mouseY;
-    SDL_GetMouseState(&mouseX, &mouseY);
-    int mouseTileX = mouseX / 32 + viewport->getCameraX();
-    int mouseTileY = mouseY / 32 + viewport->getCameraY();
+    int mouseTileX = (viewport->getMouseX() + viewport->getCameraX()) / 32;
+    int mouseTileY = (viewport->getMouseY() + viewport->getCameraY()) / 32;
 
     mFPSLabel->setCaption(toString(fps) + " FPS");
-    mFPSLabel->adjustSize();
 
-    mTileMouseLabel->setCaption("Mouse: " +
-            toString(mouseTileX) + ", " + toString(mouseTileY));
-    mTileMouseLabel->adjustSize();
+    mTileMouseLabel->setCaption("Tile: (" + toString(mouseTileX) + ", " +
+                                toString(mouseTileY) + ")");
 
     Map *currentMap = engine->getCurrentMap();
     if (currentMap)
@@ -86,20 +80,16 @@ void DebugWindow::logic()
         const std::string music =
             "Music: " + currentMap->getProperty("music");
         mMusicFileLabel->setCaption(music);
-        mMusicFileLabel->adjustSize();
 
         const std::string minimap =
             "MiniMap: " + currentMap->getProperty("minimap");
         mMiniMapLabel->setCaption(minimap);
-        mMiniMapLabel->adjustSize();
 
         const std::string map =
             "Map: " + currentMap->getProperty("_filename");
         mMapLabel->setCaption(map);
-        mMapLabel->adjustSize();
     }
 
     mParticleCountLabel->setCaption("Particle count: " +
                                     toString(Particle::particleCount));
-    mParticleCountLabel->adjustSize();
 }
