@@ -22,13 +22,7 @@
 #ifndef DEBUGWINDOW_H
 #define DEBUGWINDOW_H
 
-#include <iosfwd>
-
-#include <guichan/actionlistener.hpp>
-
-#include "window.h"
-
-#include "../guichanfwd.h"
+#include "gui/widgets/window.h"
 
 /**
  * The debug window.
@@ -54,4 +48,6 @@ class DebugWindow : public Window
         gcn::Label *mParticleCountLabel;
 };
 
+extern DebugWindow *debugWindow;
+
 #endif
