@@ -19,38 +19,38 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "gui.h"
+#include "gui/gui.h"
+
+#include "gui/focushandler.h"
+#include "gui/palette.h"
+#include "gui/sdlinput.h"
+#include "gui/skin.h"
+#include "gui/truetypefont.h"
+#include "gui/viewport.h"
+
+#include "gui/widgets/window.h"
+#include "gui/widgets/windowcontainer.h"
+
+#include "configlistener.h"
+#include "configuration.h"
+#include "graphics.h"
+#include "log.h"
+
+#include "resources/image.h"
+#include "resources/imageset.h"
+#include "resources/imageloader.h"
+#include "resources/resourcemanager.h"
 
 #include <guichan/exception.hpp>
 #include <guichan/image.hpp>
-#include <guichan/imagefont.hpp>
-
-#include "focushandler.h"
-#include "sdlinput.h"
-#include "truetypefont.h"
-#include "viewport.h"
-#include "window.h"
-#include "windowcontainer.h"
-
-#include "../configlistener.h"
-#include "../configuration.h"
-#include "../graphics.h"
-#include "../log.h"
-
-#include "../resources/image.h"
-#include "../resources/imageset.h"
-#include "../resources/resourcemanager.h"
-#include "../resources/imageloader.h"
 
 // Guichan stuff
 Gui *gui = 0;
-Viewport *viewport = 0;               /**< Viewport on the map. */
+Viewport *viewport = 0;                    /**< Viewport on the map. */
 SDLInput *guiInput = 0;
 
-// Fonts used in showing hits
-gcn::Font *hitRedFont = 0;
-gcn::Font *hitBlueFont = 0;
-gcn::Font *hitYellowFont = 0;
+// Bolded font
+gcn::Font *boldFont = 0;
 
 class GuiConfigListener : public ConfigListener
 {
@@ -61,7 +61,8 @@ class GuiConfigListener : public ConfigListener
 
         void optionChanged(const std::string &name)
         {
-            if (name == "customcursor") {
+            if (name == "customcursor")
+            {
                 bool bCustomCursor = config.getValue("customcursor", 1) == 1;
                 mGui->setUseCustomCursor(bCustomCursor);
             }
@@ -94,7 +95,7 @@ Gui::Gui(Graphics *graphics):
     mFocusHandler = new FocusHandler;
 
     // Initialize top GUI widget
-    WindowContainer *guiTop = new WindowContainer();
+    WindowContainer *guiTop = new WindowContainer;
     guiTop->setDimension(gcn::Rectangle(0, 0,
                 graphics->getWidth(), graphics->getHeight()));
     guiTop->setOpaque(false);
@@ -104,41 +105,42 @@ Gui::Gui(Graphics *graphics):
     ResourceManager *resman = ResourceManager::getInstance();
 
     // Set global font
-    std::string path = resman->getPath("fonts/dejavusans.ttf");
-    try {
-        const int fontSize = config.getValue("fontSize", 11);
+    const int fontSize = (int) config.getValue("fontSize", 11);
+    std::string fontFile = branding.getValue("font", "fonts/dejavusans.ttf");
+    std::string path = resman->getPath(fontFile);
+    try
+    {
         mGuiFont = new TrueTypeFont(path, fontSize);
+        mInfoParticleFont = new TrueTypeFont(path, fontSize, TTF_STYLE_BOLD);
     }
     catch (gcn::Exception e)
     {
-        logger->error(std::string("Unable to load dejavusans.ttf: ")
-            + e.getMessage());
+        logger->error(std::string("Unable to load '") + fontFile +
+                      std::string("': ") + e.getMessage());
+    }
+
+    // Set bold font
+    fontFile = branding.getValue("boldFont", "fonts/dejavusans-bold.ttf");
+    path = resman->getPath(fontFile);
+    try
+    {
+        boldFont = new TrueTypeFont(path, fontSize);
+    }
+    catch (gcn::Exception e)
+    {
+        logger->error(std::string("Unable to load '") + fontFile +
+                      std::string("': ") + e.getMessage());
     }
 
     gcn::Widget::setGlobalFont(mGuiFont);
 
-    // Load hits' colourful fonts
-    try {
-        hitRedFont = new gcn::ImageFont("graphics/gui/hits_red.png",
-                "0123456789");
-        hitBlueFont = new gcn::ImageFont("graphics/gui/hits_blue.png",
-                "0123456789");
-        hitYellowFont = new gcn::ImageFont("graphics/gui/hits_yellow.png",
-                "0123456789misxp ");
-    }
-    catch (gcn::Exception e)
-    {
-        logger->error(std::string("Unable to load colored hits' fonts: ")
-                + e.getMessage());
-    }
-
     // Initialize mouse cursor and listen for changes to the option
     setUseCustomCursor(config.getValue("customcursor", 1) == 1);
     mConfigListener = new GuiConfigListener(this);
     config.addListener("customcursor", mConfigListener);
 
     // Create the viewport
-    viewport = new Viewport();
+    viewport = new Viewport;
     viewport->setDimension(gcn::Rectangle(0, 0,
                 graphics->getWidth(), graphics->getHeight()));
     guiTop->add(viewport);
@@ -149,30 +151,32 @@ Gui::~Gui()
     config.removeListener("customcursor", mConfigListener);
     delete mConfigListener;
 
-    // Fonts used in showing hits
-    delete hitRedFont;
-    delete hitBlueFont;
-    delete hitYellowFont;
-
     if (mMouseCursors)
         mMouseCursors->decRef();
 
     delete mGuiFont;
+    delete boldFont;
+    delete mInfoParticleFont;
     delete viewport;
     delete getTop();
 
     delete guiInput;
+
+    SkinLoader::deleteInstance();
 }
 
 void Gui::logic()
 {
     // Fade out mouse cursor after extended inactivity
-    if (mMouseInactivityTimer < 100 * 15) {
+    if (mMouseInactivityTimer < 100 * 15)
+    {
         ++mMouseInactivityTimer;
         mMouseCursorAlpha = std::min(1.0f, mMouseCursorAlpha + 0.05f);
-    } else {
-        mMouseCursorAlpha = std::max(0.0f, mMouseCursorAlpha - 0.005f);
     }
+    else
+        mMouseCursorAlpha = std::max(0.0f, mMouseCursorAlpha - 0.005f);
+
+    guiPalette->advanceGradient();
 
     gcn::Gui::logic();
 }
@@ -217,9 +221,8 @@ void Gui::setUseCustomCursor(bool customCursor)
             mMouseCursors =
                 resman->getImageSet("graphics/gui/mouse.png", 40, 40);
 
-            if (!mMouseCursors) {
+            if (!mMouseCursors)
                 logger->error("Unable to load mouse cursors.");
-            }
         }
         else
         {
@@ -227,7 +230,8 @@ void Gui::setUseCustomCursor(bool customCursor)
             SDL_ShowCursor(SDL_ENABLE);
 
             // Unload the mouse cursor
-            if (mMouseCursors) {
+            if (mMouseCursors)
+            {
                 mMouseCursors->decRef();
                 mMouseCursors = NULL;
             }
