@@ -19,39 +19,47 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "help.h"
+#include "gui/help.h"
 
-#include "button.h"
-#include "browserbox.h"
-#include "scrollarea.h"
+#include "gui/widgets/button.h"
+#include "gui/widgets/browserbox.h"
+#include "gui/widgets/layout.h"
+#include "gui/widgets/scrollarea.h"
 
-#include "../resources/resourcemanager.h"
+#include "resources/resourcemanager.h"
 
-#include "../utils/gettext.h"
+#include "utils/gettext.h"
 
 HelpWindow::HelpWindow():
     Window(_("Help"))
 {
+    setMinWidth(300);
+    setMinHeight(250);
     setContentSize(455, 350);
     setWindowName("Help");
+    setResizable(true);
 
-    mBrowserBox = new BrowserBox();
+    setDefaultSize(500, 400, ImageRect::CENTER);
+
+    mBrowserBox = new BrowserBox;
     mBrowserBox->setOpaque(false);
     mScrollArea = new ScrollArea(mBrowserBox);
     Button *okButton = new Button(_("Close"), "close", this);
 
-    mScrollArea->setDimension(gcn::Rectangle(
-                5, 5, 445, 335 - okButton->getHeight()));
-    okButton->setPosition(
-            450 - okButton->getWidth(),
-            345 - okButton->getHeight());
+    mScrollArea->setDimension(gcn::Rectangle(5, 5, 445,
+                                             335 - okButton->getHeight()));
+    okButton->setPosition(450 - okButton->getWidth(),
+                          345 - okButton->getHeight());
 
     mBrowserBox->setLinkHandler(this);
 
-    add(mScrollArea);
-    add(okButton);
+    place(0, 0, mScrollArea, 5, 3).setPadding(3);
+    place(4, 3, okButton);
 
-    setLocationRelativeTo(getParent());
+    Layout &layout = getLayout();
+    layout.setRowHeight(0, Layout::AUTO_SET);
+
+    loadWindowState();
 }
 
 void HelpWindow::action(const gcn::ActionEvent &event)
@@ -62,7 +70,7 @@ void HelpWindow::action(const gcn::ActionEvent &event)
     }
 }
 
-void HelpWindow::handleLink(const std::string& link)
+void HelpWindow::handleLink(const std::string &link)
 {
     std::string helpFile = link;
     loadHelp(helpFile);
