@@ -22,32 +22,35 @@
 #ifndef MINIMAP_H
 #define MINIMAP_H
 
-#include "window.h"
+#include "gui/widgets/window.h"
 
 class Image;
+class Map;
 
 /**
- * Minimap dialog.
+ * Minimap window. Shows a minimap image and the name of the current map.
+ *
+ * The name of the map is defined by the map property "name". The minimap image
+ * is defined by the map property "minimap". The path to the image should be
+ * given relative to the root of the client data.
  *
  * \ingroup Interface
  */
 class Minimap : public Window
 {
     public:
-        /**
-         * Constructor.
-         */
         Minimap();
-
-        /**
-         * Destructor.
-         */
         ~Minimap();
 
         /**
          * Sets the map image that should be displayed.
          */
-        void setMapImage(Image *img);
+        void setMap(Map *map);
+
+        /**
+         * Toggles the displaying of the minimap.
+         */
+        void toggle();
 
         /**
          * Draws the minimap.
@@ -56,6 +59,9 @@ class Minimap : public Window
 
     private:
         Image *mMapImage;
+        float mWidthProportion;
+        float mHeightProportion;
+        static bool mShow;
 };
 
 extern Minimap *minimap;
