@@ -19,41 +19,50 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "ministatus.h"
+#include "gui/ministatus.h"
 
-#include "gui.h"
-#include "progressbar.h"
+#include "gui/gui.h"
+#include "gui/status.h"
 
-#include "../localplayer.h"
-#include "../configuration.h"
-#include "../graphics.h"
+#include "gui/widgets/progressbar.h"
 
-#include "../utils/tostring.h"
+#include "animatedsprite.h"
+#include "configuration.h"
+#include "graphics.h"
+#include "localplayer.h"
+
+#include "utils/stringutils.h"
 
 MiniStatusWindow::MiniStatusWindow():
-    Window("")
+    Popup("MiniStatus")
 {
-    setWindowName("MiniStatus");
-    setResizable(false);
-    setMovable(false);
-    setTitleBarHeight(0);
-
-    mHpBar = new ProgressBar(1.0f, 100, 20, 0, 171, 34);
-    mMpBar = new ProgressBar(1.0f, 100, 20, 26, 102, 230);
-    mXpBar = new ProgressBar(1.0f, 100, 20, 143, 192, 211);
+    mHpBar = new ProgressBar(0.0f, 100, 20, gcn::Color(0, 171, 34));
+#ifdef EATHENA_SUPPORT
+    mMpBar = new ProgressBar(0.0f, 100, 20, gcn::Color(26, 102, 230));
+    mXpBar = new ProgressBar(0.0f, 100, 20, gcn::Color(143, 192, 211));
+#endif
 
     mHpBar->setPosition(0, 3);
+#ifdef EATHENA_SUPPORT
     mMpBar->setPosition(mHpBar->getWidth() + 3, 3);
     mXpBar->setPosition(mMpBar->getX() + mMpBar->getWidth() + 3, 3);
+#endif
 
     add(mHpBar);
+#ifdef EATHENA_SUPPORT
     add(mMpBar);
     add(mXpBar);
+#endif
 
+#ifdef EATHENA_SUPPORT
     setContentSize(mXpBar->getX() + mXpBar->getWidth(),
                    mXpBar->getY() + mXpBar->getHeight());
-    setDefaultSize(0, 0, getWidth(), getHeight());
-    loadWindowState();
+#else
+    setContentSize(mHpBar->getX() + mHpBar->getWidth(),
+                   mHpBar->getY() + mHpBar->getHeight());
+#endif
+
+    setVisible((bool) config.getValue(getPopupName() + "Visible", true));
 }
 
 void MiniStatusWindow::setIcon(int index, AnimatedSprite *sprite)
@@ -76,43 +85,15 @@ extern volatile int tick_time;
 
 void MiniStatusWindow::update()
 {
-    // HP Bar coloration
-    if (player_node->mHp < int(player_node->mMaxHp / 3))
-    {
-        mHpBar->setColor(223, 32, 32); // Red
-    }
-    else if (player_node->mHp < int((player_node->mMaxHp / 3) * 2))
-    {
-        mHpBar->setColor(230, 171, 34); // Orange
-    }
-    else
-    {
-        mHpBar->setColor(0, 171, 34); // Green
-    }
-
-    mHpBar->setProgress((float) player_node->mHp / player_node->mMaxHp);
-    mMpBar->setProgress((float) player_node->mMp / player_node->mMaxMp);
-    if (player_node->MATK <= 0)
-        mMpBar->setColor(100, 100, 100); // grey, to indicate that we lack magic
-    else
-        mMpBar->setColor(26, 102, 230); // blue, to indicate that we have magic
-
-    mXpBar->setProgress(
-            (float) player_node->getXp() / player_node->mXpForNextLevel);
-
-    // Update labels
-    mHpBar->setText(toString(player_node->mHp));
-    mMpBar->setText(toString(player_node->mMp));
-
-    std::stringstream updatedText;
-    updatedText << (int) (
-            (float) player_node->getXp() /
-            player_node->mXpForNextLevel * 100) << "%";
+    StatusWindow::updateHPBar(mHpBar);
+#ifdef EATHENA_SUPPORT
+    StatusWindow::updateMPBar(mMpBar);
+    StatusWindow::updateXPBar(mXpBar);
 
     // Displays the number of monsters to next lvl
     // (disabled for now but interesting idea)
     /*
-    if(config.getValue("xpBarMonsterCounterExp", 0)!=0)
+    if (config.getValue("xpBarMonsterCounterExp", 0)!=0)
     {
         updatedText << " | "
             << (int)(((float)player_node->mXpForNextLevel - (float)player_node->mXp)
@@ -121,13 +102,11 @@ void MiniStatusWindow::update()
             << config.getValue("xpBarMonsterCounterName", "Monsters") <<" left...";
     }
     */
-
-    mXpBar->setText(updatedText.str());
+#endif
 
     for (unsigned int i = 0; i < mIcons.size(); i++)
         if (mIcons[i])
             mIcons[i]->update(tick_time * 10);
-
 }
 
 void MiniStatusWindow::draw(gcn::Graphics *graphics)
@@ -139,7 +118,11 @@ void MiniStatusWindow::draw(gcn::Graphics *graphics)
 void MiniStatusWindow::drawIcons(Graphics *graphics)
 {
     // Draw icons
+#ifdef TMWSERV_SUPPORT
+    int icon_x = mHpBar->getX() + mHpBar->getWidth() + 4;
+#else
     int icon_x = mXpBar->getX() + mXpBar->getWidth() + 4;
+#endif
     for (unsigned int i = 0; i < mIcons.size(); i++) {
         if (mIcons[i]) {
             mIcons[i]->draw(graphics, icon_x, 3);
