@@ -19,43 +19,27 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "register.h"
+#include "gui/register.h"
 
-#include <string>
-#include <sstream>
+#include "configuration.h"
+#include "log.h"
+#include "main.h"
 
-#include <guichan/widgets/label.hpp>
+#include "gui/login.h"
+#include "gui/okdialog.h"
 
-#include "../main.h"
-#include "../configuration.h"
-#include "../log.h"
-#include "../logindata.h"
+#include "gui/widgets/button.h"
+#include "gui/widgets/checkbox.h"
+#include "gui/widgets/label.h"
+#include "gui/widgets/layout.h"
+#include "gui/widgets/passwordfield.h"
+#include "gui/widgets/radiobutton.h"
+#include "gui/widgets/textfield.h"
 
-#include "button.h"
-#include "checkbox.h"
-#include "login.h"
-#include "passwordfield.h"
-#include "radiobutton.h"
-#include "textfield.h"
-#include "ok_dialog.h"
+#include "net/logindata.h"
 
-#include "widgets/layout.h"
-
-#include "../utils/gettext.h"
-#include "../utils/strprintf.h"
-
-/**
- * Listener used while dealing with wrong data. It is used to direct the focus
- * to the field which contained wrong data when the Ok button was pressed on
- * the error notice.
- */
-class WrongDataNoticeListener : public gcn::ActionListener {
-    public:
-        void setTarget(gcn::TextField *textField);
-        void action(const gcn::ActionEvent &event);
-    private:
-        gcn::TextField *mTarget;
-};
+#include "utils/gettext.h"
+#include "utils/stringutils.h"
 
 void WrongDataNoticeListener::setTarget(gcn::TextField *textField)
 {
@@ -65,27 +49,34 @@ void WrongDataNoticeListener::setTarget(gcn::TextField *textField)
 void WrongDataNoticeListener::action(const gcn::ActionEvent &event)
 {
     if (event.getId() == "ok")
-    {
         mTarget->requestFocus();
-    }
 }
 
-
 RegisterDialog::RegisterDialog(LoginData *loginData):
     Window(_("Register")),
     mWrongDataNoticeListener(new WrongDataNoticeListener),
     mLoginData(loginData)
 {
-    gcn::Label *userLabel = new gcn::Label(_("Name:"));
-    gcn::Label *passwordLabel = new gcn::Label(_("Password:"));
-    gcn::Label *confirmLabel = new gcn::Label(_("Confirm:"));
-    gcn::Label *serverLabel = new gcn::Label(_("Server:"));
+    gcn::Label *userLabel = new Label(_("Name:"));
+    gcn::Label *passwordLabel = new Label(_("Password:"));
+    gcn::Label *confirmLabel = new Label(_("Confirm:"));
+#ifdef EATHENA_SUPPORT
+    gcn::Label *serverLabel = new Label(_("Server:"));
+    gcn::Label *portLabel = new Label(_("Port:"));
+#else
+    gcn::Label *emailLabel = new Label(_("Email:"));
+#endif
     mUserField = new TextField(loginData->username);
     mPasswordField = new PasswordField(loginData->password);
     mConfirmField = new PasswordField;
+#ifdef EATHENA_SUPPORT
     mServerField = new TextField(loginData->hostname);
+    mPortField = new TextField(toString(loginData->port));
     mMaleButton = new RadioButton(_("Male"), "sex", true);
     mFemaleButton = new RadioButton(_("Female"), "sex", false);
+#else
+    mEmailField = new TextField;
+#endif
     mRegisterButton = new Button(_("Register"), "register", this);
     mCancelButton = new Button(_("Cancel"), "cancel", this);
 
@@ -94,13 +85,23 @@ RegisterDialog::RegisterDialog(LoginData *loginData):
     place(0, 0, userLabel);
     place(0, 1, passwordLabel);
     place(0, 2, confirmLabel);
+#ifdef EATHENA_SUPPORT
     place(1, 3, mMaleButton);
     place(2, 3, mFemaleButton);
     place(0, 4, serverLabel);
+    place(0, 5, portLabel);
+#else
+    place(0, 3, emailLabel);
+#endif
     place(1, 0, mUserField, 3).setPadding(2);
     place(1, 1, mPasswordField, 3).setPadding(2);
     place(1, 2, mConfirmField, 3).setPadding(2);
+#ifdef EATHENA_SUPPORT
     place(1, 4, mServerField, 3).setPadding(2);
+    place(1, 5, mPortField, 3).setPadding(2);
+#else
+    place(1, 3, mEmailField, 3).setPadding(2);
+#endif
     place = getPlacer(0, 2);
     place(1, 0, mRegisterButton);
     place(2, 0, mCancelButton);
@@ -109,7 +110,10 @@ RegisterDialog::RegisterDialog(LoginData *loginData):
     mUserField->addKeyListener(this);
     mPasswordField->addKeyListener(this);
     mConfirmField->addKeyListener(this);
+#ifdef EATHENA_SUPPORT
     mServerField->addKeyListener(this);
+    mPortField->addKeyListener(this);
+#endif
 
     /* TODO:
      * This is a quick and dirty way to respond to the ENTER key, regardless of
@@ -119,13 +123,20 @@ RegisterDialog::RegisterDialog(LoginData *loginData):
     mUserField->setActionEventId("register");
     mPasswordField->setActionEventId("register");
     mConfirmField->setActionEventId("register");
-    mServerField->setActionEventId("register");
+
     mUserField->addActionListener(this);
     mPasswordField->addActionListener(this);
     mConfirmField->addActionListener(this);
-    mServerField->addActionListener(this);
 
-    setLocationRelativeTo(getParent());
+#ifdef EATHENA_SUPPORT
+    mServerField->setActionEventId("register");
+    mPortField->setActionEventId("register");
+
+    mServerField->addActionListener(this);
+    mPortField->addActionListener(this);
+#endif
+
+    center();
     setVisible(true);
     mUserField->requestFocus();
     mUserField->setCaretPosition(mUserField->getText().length());
@@ -142,7 +153,7 @@ void RegisterDialog::action(const gcn::ActionEvent &event)
 {
     if (event.getId() == "cancel")
     {
-        state = LOGIN_STATE;
+        state = STATE_LOGIN;
     }
     else if (event.getId() == "register" && canSubmit())
     {
@@ -191,6 +202,8 @@ void RegisterDialog::action(const gcn::ActionEvent &event)
             error = 2;
         }
 
+        // TODO: Check if a valid email address was given
+
         if (error > 0)
         {
             if (error == 1)
@@ -206,23 +219,31 @@ void RegisterDialog::action(const gcn::ActionEvent &event)
                 mWrongDataNoticeListener->setTarget(this->mPasswordField);
             }
 
-            OkDialog *mWrongRegisterNotice =
-                new OkDialog(_("Error"), errorMsg);
-            mWrongRegisterNotice->addActionListener(mWrongDataNoticeListener);
+            OkDialog *dlg = new OkDialog(_("Error"), errorMsg);
+            dlg->addActionListener(mWrongDataNoticeListener);
         }
         else
         {
             // No errors detected, register the new user.
             mRegisterButton->setEnabled(false);
 
-            mLoginData->hostname = mServerField->getText();
-            mLoginData->port = (short) config.getValue("port", 0);
             mLoginData->username = mUserField->getText();
             mLoginData->password = mPasswordField->getText();
-            mLoginData->username += mFemaleButton->isSelected() ? "_F" : "_M";
+#ifdef EATHENA_SUPPORT
+            mLoginData->hostname = mServerField->getText();
+            mLoginData->port = getUShort(mPortField->getText());
+            mLoginData->sex =
+                    mFemaleButton->isSelected() ? GENDER_FEMALE : GENDER_MALE;
+#else
+            mLoginData->email = mEmailField->getText();
+#endif
             mLoginData->registerLogin = true;
 
-            state = ACCOUNT_STATE;
+#ifdef TMWSERV_SUPPORT
+            state = STATE_REGISTER_ATTEMPT;
+#else
+            state = STATE_ACCOUNT;
+#endif
         }
     }
 }
@@ -237,6 +258,45 @@ bool RegisterDialog::canSubmit() const
     return !mUserField->getText().empty() &&
            !mPasswordField->getText().empty() &&
            !mConfirmField->getText().empty() &&
+#ifdef EATHENA_SUPPORT
            !mServerField->getText().empty() &&
-           state == REGISTER_STATE;
+           isUShort(mPortField->getText()) &&
+#endif
+           state == STATE_REGISTER;
 }
+
+#ifdef EATHENA_SUPPORT
+bool RegisterDialog::isUShort(const std::string &str)
+{
+    if (str.empty())
+    {
+        return false;
+    }
+    unsigned long l = 0;
+    for (std::string::const_iterator strPtr = str.begin(), strEnd = str.end();
+         strPtr != strEnd; ++strPtr)
+    {
+        if (*strPtr < '0' || *strPtr > '9')
+        {
+            return false;
+        }
+        l = l * 10 + (*strPtr - '0'); // *strPtr - '0' will never be negative
+        if (l > 65535)
+        {
+            return false;
+        }
+    }
+    return true;
+}
+
+unsigned short RegisterDialog::getUShort(const std::string &str)
+{
+    unsigned long l = 0;
+    for (std::string::const_iterator strPtr = str.begin(), strEnd = str.end();
+         strPtr != strEnd; ++strPtr)
+    {
+        l = l * 10 + (*strPtr - '0');
+    }
+    return static_cast<unsigned short>(l);
+}
+#endif
