@@ -22,16 +22,29 @@
 #ifndef REGISTER_H
 #define REGISTER_H
 
-#include <iosfwd>
+#include "gui/widgets/window.h"
+
 #include <guichan/actionlistener.hpp>
 #include <guichan/keylistener.hpp>
 
-#include "window.h"
-#include "../guichanfwd.h"
+#include <string>
 
 class LoginData;
 class OkDialog;
-class WrongDataNoticeListener;
+
+/**
+ * Listener used while dealing with wrong data. It is used to direct the focus
+ * to the field which contained wrong data when the Ok button was pressed on
+ * the error notice.
+ */
+class WrongDataNoticeListener : public gcn::ActionListener
+{
+    public:
+        void setTarget(gcn::TextField *textField);
+        void action(const gcn::ActionEvent &event);
+    private:
+        gcn::TextField *mTarget;
+};
 
 /**
  * The registration dialog.
@@ -72,15 +85,42 @@ class RegisterDialog : public Window, public gcn::ActionListener,
          */
         bool canSubmit() const;
 
+#ifdef EATHENA_SUPPORT 
+        /**
+         * Function to decide whether string is an unsigned short or not
+         *
+         * @param str the string to parse
+         *
+         * @return true if str is an unsigned short, false otherwise
+         */
+        static bool isUShort(const std::string &str);
+
+        /**
+         * Converts string to an unsigned short (undefined if invalid)
+         *
+         * @param str the string to parse
+         *
+         * @return the value str represents
+         */
+        static unsigned short getUShort(const std::string &str);
+#endif
+
         gcn::TextField *mUserField;
         gcn::TextField *mPasswordField;
         gcn::TextField *mConfirmField;
+#ifdef EATHENA_SUPPORT 
         gcn::TextField *mServerField;
+        gcn::TextField *mPortField;
+#else
+        gcn::TextField *mEmailField;
+#endif
 
         gcn::Button *mRegisterButton;
         gcn::Button *mCancelButton;
+#ifdef EATHENA_SUPPORT 
         gcn::RadioButton *mMaleButton;
         gcn::RadioButton *mFemaleButton;
+#endif
 
         WrongDataNoticeListener *mWrongDataNoticeListener;
 
