@@ -22,15 +22,14 @@
 #ifndef SELL_H
 #define SELL_H
 
+#include "gui/widgets/window.h"
+
 #include <guichan/actionlistener.hpp>
 #include <guichan/selectionlistener.hpp>
 
-#include "window.h"
-
-#include "../guichanfwd.h"
+#include <SDL_types.h>
 
 class Item;
-class Network;
 class ShopItems;
 class ShopListBox;
 
@@ -47,7 +46,7 @@ class SellDialog : public Window, gcn::ActionListener, gcn::SelectionListener
          *
          * @see Window::Window
          */
-        SellDialog(Network *network);
+        SellDialog();
 
         /**
          * Destructor
@@ -81,15 +80,29 @@ class SellDialog : public Window, gcn::ActionListener, gcn::SelectionListener
          */
         void setMoney(int amount);
 
+        /**
+         * Check for current NPC
+         */
+        void logic();
+
+        /**
+         * Sets the visibility of this window.
+         */
+        void setVisible(bool visible);
+
+        /**
+         * Closes the Buy Window, as well as resetting the current npc.
+         */
+        void close();
     private:
         /**
          * Updates the state of buttons and labels.
          */
         void updateButtonsAndLabels();
 
-        Network *mNetwork;
         gcn::Button *mSellButton;
         gcn::Button *mQuitButton;
+        gcn::Button *mAddMaxButton;
         gcn::Button *mIncreaseButton;
         gcn::Button *mDecreaseButton;
         ShopListBox *mShopItemList;
@@ -107,4 +120,6 @@ class SellDialog : public Window, gcn::ActionListener, gcn::SelectionListener
         int mAmountItems;
 };
 
+extern SellDialog *sellDialog;
+
 #endif
