@@ -22,40 +22,50 @@
 #ifndef SETUP_H
 #define SETUP_H
 
-#include <list>
+#include "gui/widgets/window.h"
+
+#include "guichanfwd.h"
 
 #include <guichan/actionlistener.hpp>
 
-#include "window.h"
+#include <list>
 
 class SetupTab;
 
 /**
- * The setup dialog.
+ * The setup dialog. Displays several tabs for configuring different aspects
+ * of the game.
+ *
+ * @see Setup_Audio
+ * @see Setup_Colors
+ * @see Setup_Joystick
+ * @see Setup_Keyboard
+ * @see Setup_Players
+ * @see Setup_Video
  *
  * \ingroup GUI
  */
 class Setup : public Window, public gcn::ActionListener
 {
     public:
-        /**
-         * Constructor.
-         */
         Setup();
-
-        /**
-         * Destructor.
-         */
         ~Setup();
 
         /**
          * Event handling method.
          */
-        void
-        action(const gcn::ActionEvent &event);
+        void action(const gcn::ActionEvent &event);
+
+        /**
+         * Enables the reset button when in game.
+         */
+        void setInGame(bool inGame);
 
     private:
         std::list<SetupTab*> mTabs;
+        gcn::Button *mResetWindows;
 };
 
+extern Setup* setupWindow;
+
 #endif
