@@ -19,34 +19,34 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "setup_audio.h"
+#include "gui/setup_audio.h"
 
-#include <guichan/widgets/label.hpp>
+#include "gui/okdialog.h"
 
-#include "checkbox.h"
-#include "ok_dialog.h"
-#include "slider.h"
+#include "gui/widgets/checkbox.h"
+#include "gui/widgets/label.h"
+#include "gui/widgets/layouthelper.h"
+#include "gui/widgets/slider.h"
 
-#include "widgets/layouthelper.h"
+#include "configuration.h"
+#include "log.h"
+#include "sound.h"
 
-#include "../configuration.h"
-#include "../log.h"
-#include "../sound.h"
-
-#include "../utils/gettext.h"
+#include "utils/gettext.h"
 
 Setup_Audio::Setup_Audio():
     mMusicVolume((int)config.getValue("musicVolume", 60)),
     mSfxVolume((int)config.getValue("sfxVolume", 100)),
     mSoundEnabled(config.getValue("sound", 0)),
     mSoundCheckBox(new CheckBox(_("Sound"), mSoundEnabled)),
-    mSfxSlider(new Slider(0, 128)),
-    mMusicSlider(new Slider(0, 128))
+    mSfxSlider(new Slider(0, sound.getMaxVolume())),
+    mMusicSlider(new Slider(0, sound.getMaxVolume()))
 {
-    setOpaque(false);
+    setName(_("Audio"));
+    setDimension(gcn::Rectangle(0, 0, 250, 200));
 
-    gcn::Label *sfxLabel = new gcn::Label(_("Sfx volume"));
-    gcn::Label *musicLabel = new gcn::Label(_("Music volume"));
+    gcn::Label *sfxLabel = new Label(_("Sfx volume"));
+    gcn::Label *musicLabel = new Label(_("Music volume"));
 
     mSfxSlider->setActionEventId("sfx");
     mMusicSlider->setActionEventId("music");
@@ -72,15 +72,21 @@ Setup_Audio::Setup_Audio():
     place(0, 2, mMusicSlider);
     place(1, 2, musicLabel);
 
-    setDimension(gcn::Rectangle(0, 0, 290, 250));
+    setDimension(gcn::Rectangle(0, 0, 365, 280));
 }
 
 void Setup_Audio::apply()
 {
-    if (mSoundCheckBox->isSelected())
+    mSoundEnabled = mSoundCheckBox->isSelected();
+    mSfxVolume = (int) config.getValue("sfxVolume", 100);
+    mMusicVolume = (int) config.getValue("musicVolume", 60);
+
+    config.setValue("sound", mSoundEnabled);
+
+    if (mSoundEnabled)
     {
-        config.setValue("sound", 1);
-        try {
+        try
+        {
             sound.init();
         }
         catch (const char *err)
@@ -91,13 +97,8 @@ void Setup_Audio::apply()
     }
     else
     {
-        config.setValue("sound", 0);
         sound.close();
     }
-
-    mSoundEnabled = config.getValue("sound", 0);
-    mSfxVolume = (int)config.getValue("sfxVolume", 100);
-    mMusicVolume = (int)config.getValue("musicVolume", 60);
 }
 
 void Setup_Audio::cancel()
@@ -110,8 +111,8 @@ void Setup_Audio::cancel()
     sound.setMusicVolume(mMusicVolume);
     mMusicSlider->setValue(mMusicVolume);
 
-    config.setValue("sound", mSoundEnabled ? 1 : 0);
-    config.setValue("sfxVolume", mSfxVolume ? 1 : 0);
+    config.setValue("sound", mSoundEnabled);
+    config.setValue("sfxVolume", mSfxVolume);
     config.setValue("musicVolume", mMusicVolume);
 }
 
@@ -119,12 +120,12 @@ void Setup_Audio::action(const gcn::ActionEvent &event)
 {
     if (event.getId() == "sfx")
     {
-        config.setValue("sfxVolume", (int)mSfxSlider->getValue());
-        sound.setSfxVolume((int)mSfxSlider->getValue());
+        config.setValue("sfxVolume", (int) mSfxSlider->getValue());
+        sound.setSfxVolume((int) mSfxSlider->getValue());
     }
     else if (event.getId() == "music")
     {
-        config.setValue("musicVolume", (int)mMusicSlider->getValue());
-        sound.setMusicVolume((int)mMusicSlider->getValue());
+        config.setValue("musicVolume", (int) mMusicSlider->getValue());
+        sound.setMusicVolume((int) mMusicSlider->getValue());
     }
 }
