@@ -22,12 +22,12 @@
 #ifndef GUI_SETUP_JOYSTICK_H
 #define GUI_SETUP_JOYSTICK_H
 
-#include "setuptab.h"
+#include "guichanfwd.h"
+
+#include "gui/setuptab.h"
 
 #include <guichan/actionlistener.hpp>
 
-#include "../guichanfwd.h"
-
 class Setup_Joystick : public SetupTab, public gcn::ActionListener
 {
     public:
