@@ -1,6 +1,7 @@
 /*
- *  The Mana World
- *  Copyright (C) 2007  The Mana World Development Team
+ *  Custom keyboard shortcuts configuration
+ *  Copyright (C) 2007  Joshua Langley <joshlangley@optusnet.com.au>
+ *  Copyright (C) 2009  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
@@ -19,26 +20,24 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "setup_keyboard.h"
+#include "gui/setup_keyboard.h"
 
-#include <guichan/widgets/label.hpp>
-#include <guichan/listmodel.hpp>
+#include "gui/okdialog.h"
 
-#include "button.h"
-#include "listbox.h"
-#include "ok_dialog.h"
-#include "scrollarea.h"
+#include "gui/widgets/button.h"
+#include "gui/widgets/layouthelper.h"
+#include "gui/widgets/listbox.h"
+#include "gui/widgets/scrollarea.h"
 
-#include "widgets/layouthelper.h"
+#include "keyboardconfig.h"
 
-#include "../configuration.h"
-#include "../keyboardconfig.h"
-
-#include "../utils/gettext.h"
-#include "../utils/tostring.h"
+#include "utils/gettext.h"
+#include "utils/stringutils.h"
 
 #include <SDL_keyboard.h>
 
+#include <guichan/listmodel.hpp>
+
 /**
  * The list model for key function list.
  *
@@ -60,7 +59,7 @@ class KeyListModel : public gcn::ListModel
         /**
          * Sets element from container.
          */
-        void setElementAt(int i, std::string caption)
+        void setElementAt(int i, const std::string &caption)
         {
             mKeyFunctions[i] = caption;
         }
@@ -70,20 +69,19 @@ class KeyListModel : public gcn::ListModel
 };
 
 Setup_Keyboard::Setup_Keyboard():
-    mKeyListModel(new KeyListModel()),
+    mKeyListModel(new KeyListModel),
     mKeyList(new ListBox(mKeyListModel)),
     mKeySetting(false)
 {
     keyboard.setSetupKeyboard(this);
-    setOpaque(false);
+    setName(_("Keyboard"));
 
     refreshKeys();
 
-    mKeyList->setDimension(gcn::Rectangle(0, 0, 185, 140));
     mKeyList->addActionListener(this);
-    mKeyList->setSelected(-1);
 
     ScrollArea *scrollArea = new ScrollArea(mKeyList);
+    scrollArea->setHorizontalScrollPolicy(gcn::ScrollArea::SHOW_NEVER);
 
     mAssignKeyButton = new Button(_("Assign"), "assign", this);
     mAssignKeyButton->addActionListener(this);
@@ -100,7 +98,7 @@ Setup_Keyboard::Setup_Keyboard():
     place(0, 6, mMakeDefaultButton);
     place(3, 6, mAssignKeyButton);
 
-    setDimension(gcn::Rectangle(0, 0, 295, 250));
+    setDimension(gcn::Rectangle(0, 0, 365, 280));
 }
 
 Setup_Keyboard::~Setup_Keyboard()
@@ -140,9 +138,8 @@ void Setup_Keyboard::action(const gcn::ActionEvent &event)
 {
     if (event.getSource() == mKeyList)
     {
-        if (!mKeySetting) {
+        if (!mKeySetting)
             mAssignKeyButton->setEnabled(true);
-        }
     }
     else if (event.getId() == "assign")
     {
@@ -186,7 +183,8 @@ void Setup_Keyboard::refreshKeys()
 
 void Setup_Keyboard::keyUnresolved()
 {
-    if (mKeySetting) {
+    if (mKeySetting)
+    {
         newKeyCallback(keyboard.getNewKeyIndex());
         keyboard.setNewKeyIndex(keyboard.KEY_NO_VALUE);
     }
