@@ -1,6 +1,6 @@
 /*
  *  The Mana World
- *  Copyright (C) 2004  The Mana World Development Team
+ *  Copyright (C) 2008  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
@@ -22,20 +22,21 @@
 #ifndef GUI_SETUP_PLAYERS_H
 #define GUI_SETUP_PLAYERS_H
 
-#include "setuptab.h"
+#include "guichanfwd.h"
+
+#include "gui/setuptab.h"
+
+#include "playerrelations.h"
 
-#include "scrollarea.h"
-#include "button.h"
-#include "table.h"
 #include <guichan/actionlistener.hpp>
 
-#include "../guichanfwd.h"
-
-#include "../player_relations.h"
-
+class GuiTable;
 class PlayerTableModel;
+class StaticTableModel;
 
-class Setup_Players : public SetupTab, public gcn::ActionListener, public PlayerRelationsListener
+class Setup_Players : public SetupTab,
+                      public gcn::ActionListener,
+                      public PlayerRelationsListener
 {
 public:
     Setup_Players();
@@ -55,14 +56,18 @@ private:
     PlayerTableModel *mPlayerTableModel;
     GuiTable *mPlayerTable;
     GuiTable *mPlayerTitleTable;
-    ScrollArea *mPlayerScrollArea;
+    gcn::ScrollArea *mPlayerScrollArea;
 
-    gcn::CheckBox *mPersistIgnores;
     gcn::CheckBox *mDefaultTrading;
     gcn::CheckBox *mDefaultWhisper;
 
-    Button *mDeleteButton;
+    gcn::Button *mDeleteButton;
+
+    gcn::ListModel *mIgnoreActionChoicesModel;
     gcn::DropDown *mIgnoreActionChoicesBox;
+
+    bool mWhisperTab;
+    gcn::CheckBox *mWhisperTabCheckBox;
 };
 
 #endif
