@@ -22,8 +22,9 @@
 #ifndef SHOPLISTBOX_H
 #define SHOPLISTBOX_H
 
-#include "listbox.h"
-#include "shop.h"
+#include "gui/widgets/listbox.h"
+
+class ShopItems;
 
 /**
  * A list box, meant to be used inside a scroll area. Same as the Guichan list
@@ -55,8 +56,6 @@ class ShopListBox : public ListBox
          */
         unsigned int getRowHeight() const { return mRowHeight; }
 
-        void mousePressed(gcn::MouseEvent &event);
-
         /**
          * gives information about the current player's money
          */
@@ -84,7 +83,9 @@ class ShopListBox : public ListBox
 
         unsigned int mRowHeight; /**< Row Height */
 
+        static float mAlpha;
+
         bool mPriceCheck;
 };
 
-#endif
+#endif // SHOPLISTBOX_H
