@@ -19,30 +19,41 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <guichan/widgets/label.hpp>
+#include "gui/skill.h"
 
-#include "skill.h"
+#include "gui/table.h"
 
-#include "button.h"
-#include "listbox.h"
-#include "scrollarea.h"
-#include "windowcontainer.h"
+#include "gui/widgets/button.h"
+#include "gui/widgets/label.h"
+#include "gui/widgets/layout.h"
+#include "gui/widgets/listbox.h"
+#include "gui/widgets/scrollarea.h"
+#include "gui/widgets/windowcontainer.h"
 
-#include "../localplayer.h"
-#include "../log.h"
+#include "localplayer.h"
+#include "log.h"
 
-#include "../utils/dtor.h"
-#include "../utils/gettext.h"
-#include "../utils/strprintf.h"
-#include "../utils/xml.h"
+#include "net/net.h"
+#include "net/skillhandler.h"
+
+#include "utils/dtor.h"
+#include "utils/gettext.h"
+#include "utils/stringutils.h"
+#include "utils/xml.h"
 
 static const char *SKILLS_FILE = "skills.xml";
 
-struct SkillInfo {
+struct SkillInfo
+{
     std::string name;
     bool modifiable;
 };
 
+static const SkillInfo fakeSkillInfo = {
+    _("Mystery Skill"),
+    false
+};
+
 std::vector<SkillInfo> skill_db;
 
 static void initSkillinfo();
@@ -58,32 +69,31 @@ public:
         update();
     }
 
-    virtual int getRows() { return mEntriesNr; }
-
-    virtual int getColumnWidth(int index)
+    virtual int getRows() const
     {
-        switch (index) {
-        case 0:  return 160;
-        default: return 35;
-        }
+        return mEntriesNr;
     }
 
-    virtual int getRowHeight()
+    virtual int getColumnWidth(int index) const
+    {
+        if (index == 0)
+            return 160;
+
+        return 35;
+    }
+
+    virtual int getRowHeight() const
     {
         return 12;
     }
 
     virtual void update()
     {
-        static const SkillInfo fakeSkillInfo = {
-            _("Mystery Skill"),
-            false
-        };
-
         mEntriesNr = mDialog->getSkills().size();
         resize();
 
-        for (int i = 0; i < mEntriesNr; i++) {
+        for (int i = 0; i < mEntriesNr; i++)
+        {
             SKILL *skill = mDialog->getSkills()[i];
             SkillInfo const *info;
             char tmp[128];
@@ -95,13 +105,13 @@ public:
                 info = &fakeSkillInfo;
 
             sprintf(tmp, "%c%s", info->modifiable? ' ' : '*', info->name.c_str());
-            gcn::Label *name_label = new gcn::Label(tmp);
+            gcn::Label *name_label = new Label(tmp);
 
             sprintf(tmp, "Lv:%i", skill->lv);
-            gcn::Label *lv_label = new gcn::Label(tmp);
+            gcn::Label *lv_label = new Label(tmp);
 
             sprintf(tmp, "Sp:%i", skill->sp);
-            gcn::Label *sp_label = new gcn::Label(tmp);
+            gcn::Label *sp_label = new Label(tmp);
 
             set(i, 0, name_label);
             set(i, 1, lv_label);
@@ -120,44 +130,43 @@ SkillDialog::SkillDialog():
 {
     initSkillinfo();
     mTableModel = new SkillGuiTableModel(this);
-    mTable.setModel(mTableModel);
-    mTable.setLinewiseSelection(true);
+    mTable = new GuiTable(mTableModel);
+    mTable->setOpaque(false);
+    mTable->setLinewiseSelection(true);
+    mTable->setWrappingEnabled(true);
+    mTable->setActionEventId("skill");
+    mTable->addActionListener(this);
 
     setWindowName("Skills");
     setCloseButton(true);
-    setDefaultSize(windowContainer->getWidth() - 260, 25, 255, 260);
+    setDefaultSize(255, 260, ImageRect::CENTER);
 
-//    mSkillListBox = new ListBox(this);
-    ScrollArea *skillScrollArea = new ScrollArea(&mTable);
-    mPointsLabel = new gcn::Label(strprintf(_("Skill points: %d"), 0));
+    setMinHeight(50 + mTableModel->getHeight());
+    setMinWidth(200);
+
+    ScrollArea *skillScrollArea = new ScrollArea(mTable);
+    mPointsLabel = new Label(strprintf(_("Skill points: %d"), 0));
     mIncButton = new Button(_("Up"), "inc", this);
     mUseButton = new Button(_("Use"), "use", this);
     mUseButton->setEnabled(false);
 
-//    mSkillListBox->setActionEventId("skill");
-    mTable.setActionEventId("skill");
-
     skillScrollArea->setHorizontalScrollPolicy(gcn::ScrollArea::SHOW_NEVER);
-    skillScrollArea->setDimension(gcn::Rectangle(5, 5, 230, 180));
-    mPointsLabel->setDimension(gcn::Rectangle(8, 190, 200, 16));
-    mIncButton->setPosition(skillScrollArea->getX(), 210);
-    mUseButton->setPosition(mIncButton->getX() + mIncButton->getWidth() + 5,
-        210);
 
-    add(skillScrollArea);
-    add(mPointsLabel);
-    add(mIncButton);
-    add(mUseButton);
+    place(0, 0, skillScrollArea, 5).setPadding(3);
+    place(0, 1, mPointsLabel, 4);
+    place(3, 2, mIncButton);
+    place(4, 2, mUseButton);
 
-//    mSkillListBox->addActionListener(this);
-    mTable.addActionListener(this);
+    Layout &layout = getLayout();
+    layout.setRowHeight(0, Layout::AUTO_SET);
 
-    setLocationRelativeTo(getParent());
+    center();
     loadWindowState();
 }
 
 SkillDialog::~SkillDialog()
 {
+    delete_all(mSkillList);
 }
 
 void SkillDialog::action(const gcn::ActionEvent &event)
@@ -165,22 +174,25 @@ void SkillDialog::action(const gcn::ActionEvent &event)
     if (event.getId() == "inc")
     {
         // Increment skill
-        int selectedSkill = mTable.getSelectedRow();//mSkillListBox->getSelected();
+        int selectedSkill = mTable->getSelectedRow();
         if (selectedSkill >= 0)
-        {
-            player_node->raiseSkill(mSkillList[selectedSkill]->id);
-        }
+            Net::getSkillHandler()->up(mSkillList[selectedSkill]->id);
     }
-    else if (event.getId() == "skill")
+    else if (event.getId() == "skill" && mTable->getSelectedRow() > -1)
     {
-        mIncButton->setEnabled(
-                mTable.getSelectedRow() > -1 &&
-                player_node->mSkillPoint > 0);
+        SKILL *skill = mSkillList[mTable->getSelectedRow()];
+        SkillInfo const *info;
+
+        if (skill->id >= 0 && (unsigned int) skill->id < skill_db.size())
+            info = &skill_db[skill->id];
+        else
+            info = &fakeSkillInfo;
+
+        mIncButton->setEnabled(player_node->mSkillPoint > 0 &&
+                               info->modifiable);
     }
     else if (event.getId() == "close")
-    {
         setVisible(false);
-    }
 }
 
 void SkillDialog::update()
@@ -188,9 +200,10 @@ void SkillDialog::update()
     mPointsLabel->setCaption(strprintf(_("Skill points: %d"),
                                        player_node->mSkillPoint));
 
-    int selectedSkill = mTable.getSelectedRow();
+    int selectedSkill = mTable->getSelectedRow();
 
-    if (selectedSkill >= 0) {
+    if (selectedSkill >= 0)
+    {
         int skillId = mSkillList[selectedSkill]->id;
         bool modifiable;
 
@@ -201,10 +214,12 @@ void SkillDialog::update()
 
         mIncButton->setEnabled(modifiable
                                && player_node->mSkillPoint > 0);
-    } else
+    }
+    else
         mIncButton->setEnabled(false);
 
     mTableModel->update();
+    setMinHeight(50 + mTableModel->getHeight());
 }
 
 int SkillDialog::getNumberOfElements()
@@ -214,17 +229,17 @@ int SkillDialog::getNumberOfElements()
 
 bool SkillDialog::hasSkill(int id)
 {
-    for (unsigned int i = 0; i < mSkillList.size(); i++) {
-        if (mSkillList[i]->id == id) {
+    for (unsigned int i = 0; i < mSkillList.size(); i++)
+    {
+        if (mSkillList[i]->id == id)
             return true;
-        }
     }
     return false;
 }
 
 void SkillDialog::addSkill(int id, int lvl, int mp)
 {
-    SKILL *tmp = new SKILL();
+    SKILL *tmp = new SKILL;
     tmp->id = id;
     tmp->lv = lvl;
     tmp->sp = mp;
@@ -233,8 +248,10 @@ void SkillDialog::addSkill(int id, int lvl, int mp)
 
 void SkillDialog::setSkill(int id, int lvl, int mp)
 {
-    for (unsigned int i = 0; i < mSkillList.size(); i++) {
-        if (mSkillList[i]->id == id) {
+    for (unsigned int i = 0; i < mSkillList.size(); i++)
+    {
+        if (mSkillList[i]->id == id)
+        {
             mSkillList[i]->lv = lvl;
             mSkillList[i]->sp = mp;
         }
@@ -271,7 +288,8 @@ static void initSkillinfo()
             std::string name = XML::getProperty(node, "name", "");
             bool modifiable = !atoi(XML::getProperty(node, "fixed", "0").c_str());
 
-            if (index >= 0) {
+            if (index >= 0)
+            {
                 skill_db.resize(index + 1, emptySkillInfo);
                 skill_db[index].name = name;
                 skill_db[index].modifiable = modifiable;
