@@ -22,21 +22,20 @@
 #ifndef SKILL_H
 #define SKILL_H
 
-#include <vector>
+#include "gui/widgets/window.h"
 
-#include <guichan/listmodel.hpp>
 #include <guichan/actionlistener.hpp>
 
-#include "window.h"
-#include "table.h"
+#include <vector>
 
-#include "../guichanfwd.h"
-
-struct SKILL {
+struct SKILL
+{
     short id;      /**< Index into "skill_db" array */
     short lv, sp;
 };
 
+class GuiTable;
+class ScrollArea;
 class SkillGuiTableModel;
 
 /**
@@ -71,7 +70,8 @@ class SkillDialog : public Window, public gcn::ActionListener
         const std::vector<SKILL*>& getSkills() const { return mSkillList; }
 
     private:
-        GuiTable mTable;//gcn::ListBox *mSkillListBox;
+        GuiTable *mTable;
+        ScrollArea *skillScrollArea;
         SkillGuiTableModel *mTableModel;
         gcn::Label *mPointsLabel;
         gcn::Button *mIncButton;
