@@ -19,25 +19,28 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "resizegrip.h"
+#include "gui/widgets/resizegrip.h"
+
+#include "configuration.h"
+#include "graphics.h"
+
+#include "resources/image.h"
+#include "resources/resourcemanager.h"
 
 #include <guichan/graphics.hpp>
 
-#include "../../graphics.h"
-
-#include "../../resources/image.h"
-#include "../../resources/resourcemanager.h"
-
 Image *ResizeGrip::gripImage = 0;
 int ResizeGrip::mInstances = 0;
+float ResizeGrip::mAlpha = 1.0;
 
-ResizeGrip::ResizeGrip()
+ResizeGrip::ResizeGrip(const std::string &image)
 {
     if (mInstances == 0)
     {
         // Load the grip image
         ResourceManager *resman = ResourceManager::getInstance();
-        gripImage = resman->getImage("graphics/gui/resize.png");
+        gripImage = resman->getImage(image);
+        gripImage->setAlpha(mAlpha);
     }
 
     mInstances++;
@@ -51,13 +54,16 @@ ResizeGrip::~ResizeGrip()
     mInstances--;
 
     if (mInstances == 0)
-    {
         gripImage->decRef();
-    }
 }
 
-void
-ResizeGrip::draw(gcn::Graphics *graphics)
+void ResizeGrip::draw(gcn::Graphics *graphics)
 {
+    if (config.getValue("guialpha", 0.8) != mAlpha)
+    {
+        mAlpha = config.getValue("guialpha", 0.8);
+        gripImage->setAlpha(mAlpha);
+    }
+
     static_cast<Graphics*>(graphics)->drawImage(gripImage, 0, 0);
 }
