@@ -29,17 +29,19 @@ ImageParticle::ImageParticle(Map *map, Image *image):
     Particle(map),
     mImage(image)
 {
-    if (mImage) mImage->incRef();
+    if (mImage)
+        mImage->incRef();
 }
 
 ImageParticle::~ImageParticle()
 {
-    if (mImage) mImage->decRef();
+    if (mImage)
+        mImage->decRef();
 }
 
 void ImageParticle::draw(Graphics *graphics, int offsetX, int offsetY) const
 {
-    if (!mAlive)
+    if (!mAlive || !mImage)
         return;
 
     int screenX = (int) mPos.x + offsetX - mImage->getWidth() / 2;
