@@ -19,30 +19,42 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _INVENTORY_H
-#define _INVENTORY_H
+#ifndef INVENTORY_H
+#define INVENTORY_H
 
 class Item;
 
-#define INVENTORY_SIZE 102
+#ifdef EATHENA_SUPPORT
+const int INVENTORY_SIZE = 100;
+#else
+const int INVENTORY_SIZE = 50;
+#endif
+const int STORAGE_SIZE = 301;
 
 class Inventory
 {
     public:
         /**
          * Constructor.
+         *
+         * @param size the number of items that fit in the inventory
          */
-        Inventory();
+        Inventory(int size);
 
         /**
          * Destructor.
          */
         ~Inventory();
 
+        /**
+         * Returns the size that this instance is configured for.
+         */
+        int getSize() const { return mSize; }
+
         /**
          * Returns the item at the specified index.
          */
-        Item* getItem(int index) const;
+        Item *getItem(int index) const;
 
         /**
          * Searches for the specified item by it's id.
@@ -50,17 +62,17 @@ class Inventory
          * @param itemId The id of the item to be searched.
          * @return Item found on success, NULL on failure.
          */
-        Item* findItem(int itemId) const;
+        Item *findItem(int itemId) const;
 
         /**
          * Adds a new item in a free slot.
          */
-        void addItem(int id, int quantity, bool equipment);
+        void addItem(int id, int quantity, bool equipment = false);
 
         /**
          * Sets the item at the given position.
          */
-        void setItem(int index, int id, int quantity, bool equipment);
+        void setItem(int index, int id, int quantity, bool equipment = false);
 
         /**
          * Remove a item from the inventory.
@@ -73,7 +85,7 @@ class Inventory
         void removeItemAt(int index);
 
         /**
-         * Checks if the given item is in the inventory
+         * Checks if the given item is in the inventory.
          */
         bool contains(Item *item) const;
 
@@ -97,13 +109,11 @@ class Inventory
          */
         int getLastUsedSlot() const;
 
-        /**
-         * Returns the number of slots available in the inventory.
-         */
-        int getInventorySize() const;
+        static const int NO_SLOT_INDEX = -1; /**< Slot has no index. */
 
     protected:
         Item **mItems;  /**< The holder of items */
+        int mSize;      /**< The max number of inventory items */
 };
 
 #endif
