@@ -19,24 +19,24 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "map.h"
-
 #include <queue>
 
 #include "beingmanager.h"
 #include "configuration.h"
 #include "game.h"
 #include "graphics.h"
+#include "map.h"
 #include "particle.h"
+#include "simpleanimation.h"
 #include "sprite.h"
 #include "tileset.h"
 
-#include "resources/resourcemanager.h"
 #include "resources/ambientoverlay.h"
 #include "resources/image.h"
+#include "resources/resourcemanager.h"
 
 #include "utils/dtor.h"
-#include "utils/tostring.h"
+#include "utils/stringutils.h"
 
 extern volatile int tick_time;
 
@@ -48,7 +48,9 @@ struct Location
     /**
      * Constructor.
      */
-    Location(int px, int py, MetaTile *ptile):x(px),y(py),tile(ptile) {};
+    Location(int px, int py, MetaTile *ptile):
+        x(px), y(py), tile(ptile)
+    {}
 
     /**
      * Comparison operator.
@@ -63,29 +65,35 @@ struct Location
 };
 
 TileAnimation::TileAnimation(Animation *ani):
-    mAnimation(ani),
     mLastImage(NULL)
 {
+    mAnimation = new SimpleAnimation(ani);
 }
 
-void TileAnimation::update()
+TileAnimation::~TileAnimation()
 {
-    //update animation
-    mAnimation.update(1);
+    delete mAnimation;
+}
+
+void TileAnimation::update(int ticks)
+{
+    if (!mAnimation)
+        return;
+
+    // update animation
+    mAnimation->update(ticks);
 
     // exchange images
-    Image *img = mAnimation.getCurrentImage();
+    Image *img = mAnimation->getCurrentImage();
     if (img != mLastImage)
     {
-        for (std::list<std::pair<MapLayer*, int> >::iterator i = mAffected.begin();
-             i != mAffected.end();
-             i++)
+        for (std::list<std::pair<MapLayer*, int> >::iterator i =
+             mAffected.begin(); i != mAffected.end(); i++)
         {
             i->first->setTile(i->second, img);
         }
         mLastImage = img;
     }
-
 }
 
 MapLayer::MapLayer(int x, int y, int width, int height, bool isFringeLayer):
@@ -113,10 +121,8 @@ Image* MapLayer::getTile(int x, int y) const
     return mTiles[x + y * mWidth];
 }
 
-void MapLayer::draw(Graphics *graphics,
-                    int startX, int startY,
-                    int endX, int endY,
-                    int scrollX, int scrollY,
+void MapLayer::draw(Graphics *graphics, int startX, int startY,
+                    int endX, int endY, int scrollX, int scrollY,
                     const Sprites &sprites) const
 {
     startX -= mX;
@@ -135,8 +141,10 @@ void MapLayer::draw(Graphics *graphics,
     {
         // If drawing the fringe layer, make sure all sprites above this row of
         // tiles have been drawn
-        if (mIsFringeLayer) {
-            while (si != sprites.end() && (*si)->getPixelY() <= y * 32 - 32) {
+        if (mIsFringeLayer)
+        {
+            while (si != sprites.end() && (*si)->getPixelY() <= y * 32)
+            {
                 (*si)->draw(graphics, -scrollX, -scrollY);
                 si++;
             }
@@ -145,7 +153,8 @@ void MapLayer::draw(Graphics *graphics,
         for (int x = startX; x < endX; x++)
         {
             Image *img = getTile(x, y);
-            if (img) {
+            if (img)
+            {
                 const int px = (x + mX) * 32 - scrollX;
                 const int py = (y + mY) * 32 - scrollY + 32 - img->getHeight();
                 graphics->drawImage(img, px, py);
@@ -154,8 +163,10 @@ void MapLayer::draw(Graphics *graphics,
     }
 
     // Draw any remaining sprites
-    if (mIsFringeLayer) {
-        while (si != sprites.end()) {
+    if (mIsFringeLayer)
+    {
+        while (si != sprites.end())
+        {
             (*si)->draw(graphics, -scrollX, -scrollY);
             si++;
         }
@@ -172,12 +183,21 @@ Map::Map(int width, int height, int tileWidth, int tileHeight):
     const int size = mWidth * mHeight;
 
     mMetaTiles = new MetaTile[size];
+    for (int i = 0; i < NB_BLOCKTYPES; i++)
+    {
+        mOccupation[i] = new int[size];
+        memset(mOccupation[i], 0, size * sizeof(int));
+    }
 }
 
 Map::~Map()
 {
     // delete metadata, layers, tilesets and overlays
     delete[] mMetaTiles;
+    for (int i = 0; i < NB_BLOCKTYPES; i++)
+    {
+        delete[] mOccupation[i];
+    }
     delete_all(mLayers);
     delete_all(mTilesets);
     delete_all(mOverlays);
@@ -228,14 +248,14 @@ bool spriteCompare(const Sprite *a, const Sprite *b)
     return a->getPixelY() < b->getPixelY();
 }
 
-void Map::update()
+void Map::update(int ticks)
 {
     //update animated tiles
     for (std::map<int, TileAnimation*>::iterator iAni = mTileAnimations.begin();
          iAni != mTileAnimations.end();
          iAni++)
     {
-        iAni->second->update();
+        iAni->second->update(ticks);
     }
 }
 
@@ -256,7 +276,8 @@ void Map::draw(Graphics *graphics, int scrollX, int scrollY)
 
     // draw the game world
     Layers::const_iterator layeri = mLayers.begin();
-    for (; layeri != mLayers.end(); ++layeri) {
+    for (; layeri != mLayers.end(); ++layeri)
+    {
         (*layeri)->draw(graphics,
                         startX, startY, endX, endY,
                         scrollX, scrollY,
@@ -267,6 +288,59 @@ void Map::draw(Graphics *graphics, int scrollX, int scrollY)
             (int) config.getValue("OverlayDetail", 2));
 }
 
+void Map::drawCollision(Graphics *graphics, int scrollX, int scrollY)
+{
+    int endPixelY = graphics->getHeight() + scrollY + mTileHeight - 1;
+    int startX = scrollX / mTileWidth;
+    int startY = scrollY / mTileHeight;
+    int endX = (graphics->getWidth() + scrollX + mTileWidth - 1) / mTileWidth;
+    int endY = endPixelY / mTileHeight;
+
+    if (startX < 0) startX = 0;
+    if (startY < 0) startY = 0;
+    if (endX > mWidth) endX = mWidth;
+    if (endY > mHeight) endY = mHeight;
+
+    for (int y = startY; y < endY; y++)
+    {
+        for (int x = startX; x < endX; x++)
+        {
+            graphics->setColor(gcn::Color(0, 0, 0, 64));
+                graphics->drawRectangle(gcn::Rectangle(
+                    x * mTileWidth - scrollX,
+                    y * mTileWidth - scrollY,
+                    33, 33));
+
+            if (!getWalk(x, y, BLOCKMASK_WALL))
+            {
+                graphics->setColor(gcn::Color(0, 0, 200, 64));
+                graphics->fillRectangle(gcn::Rectangle(
+                    x * mTileWidth - scrollX,
+                    y * mTileWidth - scrollY,
+                    32, 32));
+            }
+
+            if (!getWalk(x, y, BLOCKMASK_MONSTER))
+            {
+                graphics->setColor(gcn::Color(200, 0, 0, 64));
+                graphics->fillRectangle(gcn::Rectangle(
+                    x * mTileWidth - scrollX,
+                    y * mTileWidth - scrollY,
+                    32, 32));
+            }
+
+            if (!getWalk(x, y, BLOCKMASK_CHARACTER))
+            {
+                graphics->setColor(gcn::Color(0, 200, 0, 64));
+                graphics->fillRectangle(gcn::Rectangle(
+                    x * mTileWidth - scrollX,
+                    y * mTileWidth - scrollY,
+                    32, 32));
+            }
+        }
+    }
+}
+
 void Map::drawOverlay(Graphics *graphics,
                       float scrollX, float scrollY, int detail)
 {
@@ -310,7 +384,7 @@ void Map::drawOverlay(Graphics *graphics,
 class ContainsGidFunctor
 {
     public:
-        bool operator() (const Tileset* set) const
+        bool operator() (const Tileset *set) const
         {
             return (set->getFirstGid() <= gid &&
                     gid - set->getFirstGid() < (int)set->size());
@@ -318,7 +392,7 @@ class ContainsGidFunctor
         int gid;
 } containsGid;
 
-Tileset* Map::getTilesetWithGid(int gid) const
+Tileset *Map::getTilesetWithGid(int gid) const
 {
     containsGid.gid = gid;
 
@@ -328,37 +402,66 @@ Tileset* Map::getTilesetWithGid(int gid) const
     return (i == mTilesets.end()) ? NULL : *i;
 }
 
-void Map::setWalk(int x, int y, bool walkable)
+void Map::blockTile(int x, int y, BlockType type)
 {
-    mMetaTiles[x + y * mWidth].walkable = walkable;
+    if (type == BLOCKTYPE_NONE || !contains(x, y))
+        return;
+
+    const int tileNum = x + y * mWidth;
+
+    if ((++mOccupation[type][tileNum]) > 0)
+    {
+        switch (type)
+        {
+            case BLOCKTYPE_WALL:
+                mMetaTiles[tileNum].blockmask |= BLOCKMASK_WALL;
+                break;
+            case BLOCKTYPE_CHARACTER:
+                mMetaTiles[tileNum].blockmask |= BLOCKMASK_CHARACTER;
+                break;
+            case BLOCKTYPE_MONSTER:
+                mMetaTiles[tileNum].blockmask |= BLOCKMASK_MONSTER;
+                break;
+            default:
+                // shut up!
+                break;
+        }
+    }
 }
 
+bool Map::getWalk(int x, int y, unsigned char walkmask) const
+{
+    // You can't walk outside of the map
+    if (!contains(x, y))
+        return false;
+
+    // Check if the tile is walkable
+    return !(mMetaTiles[x + y * mWidth].blockmask & walkmask);
+}
+
+#ifdef EATHENA_SUPPORT
 bool Map::occupied(int x, int y) const
 {
-    Beings &beings = beingManager->getAll();
-    for (BeingIterator i = beings.begin(); i != beings.end(); i++)
+    const Beings &beings = beingManager->getAll();
+    for (Beings::const_iterator i = beings.begin(); i != beings.end(); i++)
     {
+        const Being *being = *i;
+
         // job 45 is a portal, they don't collide
-        if ((*i)->mX == x && (*i)->mY == y && (*i)->mJob != 45)
-        {
+        if (being->mX == x && being->mY == y && being->mJob != 45)
             return true;
-        }
     }
 
     return false;
 }
-
-bool Map::tileCollides(int x, int y) const
-{
-    return !(contains(x, y) && mMetaTiles[x + y * mWidth].walkable);
-}
+#endif
 
 bool Map::contains(int x, int y) const
 {
     return x >= 0 && y >= 0 && x < mWidth && y < mHeight;
 }
 
-MetaTile* Map::getMetaTile(int x, int y)
+MetaTile *Map::getMetaTile(int x, int y) const
 {
     return &mMetaTiles[x + y * mWidth];
 }
@@ -374,7 +477,23 @@ void Map::removeSprite(SpriteIterator iterator)
     mSprites.erase(iterator);
 }
 
-Path Map::findPath(int startX, int startY, int destX, int destY)
+const std::string &Map::getMusicFile() const
+{
+    return getProperty("music");
+}
+
+const std::string &Map::getName() const
+{
+    if (hasProperty("name"))
+        return getProperty("name");
+
+    return getProperty("mapname");
+}
+
+static int const basicCost = 100;
+
+Path Map::findPath(int startX, int startY, int destX, int destY,
+                   unsigned char walkmask, int maxCost)
 {
     // Path to be built up (empty by default)
     Path path;
@@ -382,6 +501,9 @@ Path Map::findPath(int startX, int startY, int destX, int destY)
     // Declare open list, a list with open tiles sorted on F cost
     std::priority_queue<Location> openList;
 
+    // Return when destination not walkable
+    if (!getWalk(destX, destY, walkmask)) return path;
+
     // Reset starting tile's G cost to 0
     MetaTile *startTile = getMetaTile(startX, startY);
     startTile->Gcost = 0;
@@ -426,42 +548,56 @@ Path Map::findPath(int startX, int startY, int destX, int destY)
 
                 MetaTile *newTile = getMetaTile(x, y);
 
-                // Skip if the tile is on the closed list or collides unless
-                // its the destination tile
+                // Skip if the tile is on the closed list or is not walkable
+                // unless its the destination tile
                 if (newTile->whichList == mOnClosedList ||
-                        (tileCollides(x, y) && !(x == destX && y == destY)))
+                    ((newTile->blockmask & walkmask)
+                     && !(x == destX && y == destY)))
                 {
                     continue;
                 }
 
                 // When taking a diagonal step, verify that we can skip the
-                // corner. We allow skipping past beings but not past non-
-                // walkable tiles.
+                // corner.
                 if (dx != 0 && dy != 0)
                 {
                     MetaTile *t1 = getMetaTile(curr.x, curr.y + dy);
                     MetaTile *t2 = getMetaTile(curr.x + dx, curr.y);
 
-                    if (!(t1->walkable && t2->walkable))
-                    {
+                    if ((t1->blockmask | t2->blockmask) & BLOCKMASK_WALL)
                         continue;
-                    }
                 }
 
-                // Calculate G cost for this route, 10 for moving straight and
-                // 14 for moving diagonal (sqrt(200) = 14.1421...)
-                int Gcost = curr.tile->Gcost + ((dx == 0 || dy == 0) ? 10 : 14);
+                // Calculate G cost for this route, ~sqrt(2) for moving diagonal
+                int Gcost = curr.tile->Gcost +
+                    (dx == 0 || dy == 0 ? basicCost : basicCost * 362 / 256);
 
+                /* Demote an arbitrary direction to speed pathfinding by
+                   adding a defect (TODO: change depending on the desired
+                   visual effect, e.g. a cross-product defect toward
+                   destination).
+                   Important: as long as the total defect along any path is
+                   less than the basicCost, the pathfinder will still find one
+                   of the shortest paths! */
+                if (dx == 0 || dy == 0)
+                {
+                    // Demote horizontal and vertical directions, so that two
+                    // consecutive directions cannot have the same Fcost.
+                    ++Gcost;
+                }
+
+#ifdef EATHENA_SUPPORT
                 // It costs extra to walk through a being (needs to be enough
                 // to make it more attractive to walk around).
                 if (occupied(x, y))
                 {
-                    Gcost += 30;
+                    Gcost += 3 * basicCost;
                 }
+#endif
 
                 // Skip if Gcost becomes too much
                 // Warning: probably not entirely accurate
-                if (Gcost > 200)
+                if (Gcost > maxCost * basicCost)
                 {
                     continue;
                 }
@@ -469,8 +605,14 @@ Path Map::findPath(int startX, int startY, int destX, int destY)
                 if (newTile->whichList != mOnOpenList)
                 {
                     // Found a new tile (not on open nor on closed list)
-                    // Update Hcost of the new tile using Manhatten distance
-                    newTile->Hcost = 10 * (abs(x - destX) + abs(y - destY));
+
+                    /* Update Hcost of the new tile. The pathfinder does not
+                       work reliably if the heuristic cost is higher than the
+                       real cost. In particular, using Manhattan distance is
+                       forbidden here. */
+                    int dx = std::abs(x - destX), dy = std::abs(y - destY);
+                    newTile->Hcost = std::abs(dx - dy) * basicCost +
+                        std::min(dx, dy) * (basicCost * 362 / 256);
 
                     // Set the current tile as the parent of the new tile
                     newTile->parentX = curr.x;
@@ -545,18 +687,21 @@ void Map::addParticleEffect(const std::string &effectFile, int x, int y)
     particleEffects.push_back(newEffect);
 }
 
-void Map::initializeParticleEffects(Particle* particleEngine)
+void Map::initializeParticleEffects(Particle *particleEngine)
 {
-    for (std::list<ParticleEffectData>::iterator i = particleEffects.begin();
-         i != particleEffects.end();
-         i++
-        )
+    if (config.getValue("particleeffects", 1))
     {
-        particleEngine->addEffect(i->file, i->x, i->y);
+        for (std::list<ParticleEffectData>::iterator i = particleEffects.begin();
+             i != particleEffects.end();
+             i++
+            )
+        {
+            particleEngine->addEffect(i->file, i->x, i->y);
+        }
     }
 }
 
-TileAnimation* Map::getAnimationForGid(int gid)
+TileAnimation *Map::getAnimationForGid(int gid)
 {
     std::map<int, TileAnimation*>::iterator i = mTileAnimations.find(gid);
     if (i == mTileAnimations.end())
