@@ -30,13 +30,15 @@ class Text;
 class Monster : public Being
 {
     public:
-        Monster(Uint32 id, Uint16 job, Map *map);
+        Monster(int id, int job, Map *map);
 
         ~Monster();
 
+#ifdef EATHENA_SUPPORT
         virtual void logic();
+#endif
 
-        virtual void setAction(Uint8 action);
+        virtual void setAction(Action action, int attackType = 0);
 
         virtual Type getType() const;
 
@@ -47,30 +49,52 @@ class Monster : public Being
          * Handles an attack of another being by this monster. Plays a hit or
          * miss sound when appropriate.
          *
-         * @param victim The attacked being.
-         * @param damage The amount of damage dealt (0 means miss).
+         * @param victim the victim being
+         * @param damage the amount of damage dealt (0 means miss)
+         * @param type the attack type
          */
-        virtual void handleAttack(Being *victim, int damage);
+#ifdef TMWSERV_SUPPORT
+        virtual void handleAttack();
+#else
+        virtual void handleAttack(Being *victim, int damage, AttackType type);
+#endif
 
         /**
          * Puts a damage bubble above this monster and plays the hurt sound
          *
-         * @param amount The amount of damage.
+         * @param attacker the attacking being
+         * @param damage the amount of damage recieved (0 means miss)
+         * @param type the attack type
          */
-        virtual void takeDamage(int amount);
+        virtual void takeDamage(Being *attacker, int amount, AttackType type);
 
         /**
          * Returns the MonsterInfo, with static data about this monster.
          */
-        const MonsterInfo&
-        getInfo() const;
+        const MonsterInfo& getInfo() const;
 
         /**
          * Determine whether the mob should show it's name
          */
-        void showName(bool show);
+        void setShowName(bool show);
+
+        /**
+         * Gets the way the monster is blocked by other objects
+         */
+        virtual unsigned char getWalkMask() const
+        {
+            return Map::BLOCKMASK_WALL
+                    | Map::BLOCKMASK_CHARACTER
+                    | Map::BLOCKMASK_MONSTER;
+        }
 
     protected:
+        /**
+         * Gets the way the monster blocks pathfinding for other objects
+         */
+        virtual Map::BlockType getBlockType() const
+        { return Map::BLOCKTYPE_MONSTER; }
+
         /**
          * Update the text when the monster moves
          */
