@@ -1,6 +1,6 @@
 /*
  *  The Mana World
- *  Copyright (C) 2004  The Mana World Development Team
+ *  Copyright (C) 2009  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
@@ -19,26 +19,34 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef NET_LOGINHANDLER_H
-#define NET_LOGINHANDLER_H
+#ifndef LOGINHANDLER_H
+#define LOGINHANDLER_H
 
-#include "messagehandler.h"
-#include <string>
+#include "logindata.h"
 
-struct LoginData;
+#include <iosfwd>
 
-class LoginHandler : public MessageHandler
+namespace Net {
+
+class LoginHandler
 {
     public:
-        LoginHandler();
+        virtual void loginAccount(LoginData *loginData) = 0;
 
-        void handleMessage(MessageIn *msg);
+        virtual void changeEmail(const std::string &email) = 0;
 
-        void setLoginData(LoginData *loginData) { mLoginData = loginData; };
+        virtual void changePassword(const std::string &username,
+                                    const std::string &oldPassword,
+                                    const std::string &newPassword) = 0;
 
-    private:
-        LoginData *mLoginData;
-        std::string mUpdateHost;
+        virtual void chooseServer(int server) = 0;
+
+        virtual void registerAccount(LoginData *loginData) = 0;
+
+        virtual void unregisterAccount(const std::string &username,
+                                       const std::string &password) = 0;
 };
 
-#endif
+} // namespace Net
+
+#endif // LOGINHANDLER_H
