@@ -19,25 +19,37 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "messagehandler.h"
+#include "net/messagehandler.h"
+
+#ifdef TMWSERV_SUPPORT
+#include "net/tmwserv/network.h"
+#else
+#include "net/ea/network.h"
+#endif
 
 #include <cassert>
 
-#include "network.h"
-
-MessageHandler::MessageHandler():
-    mNetwork(0)
+MessageHandler::MessageHandler()
+#ifdef EATHENA_SUPPORT
+    : mNetwork(0)
+#endif
 {
 }
 
 MessageHandler::~MessageHandler()
 {
+#ifdef TMWSERV_SUPPORT
+    Net::unregisterHandler(this);
+#else
     if (mNetwork)
         mNetwork->unregisterHandler(this);
+#endif
 }
 
+#ifdef EATHENA_SUPPORT
 void MessageHandler::setNetwork(Network *network)
 {
     assert(!(network && mNetwork));
     mNetwork = network;
 }
+#endif
