@@ -24,9 +24,16 @@
 
 #include <SDL_types.h>
 
-class MessageIn;
-class Network;
+#include <memory>
 
+class MessageIn;
+#ifdef EATHENA_SUPPORT
+class Network;
+#endif
+
+/**
+ * \ingroup Network
+ */
 class MessageHandler
 {
     public:
@@ -35,12 +42,16 @@ class MessageHandler
         MessageHandler();
         virtual ~MessageHandler();
 
-        virtual void handleMessage(MessageIn *msg) =0;
+        virtual void handleMessage(MessageIn &msg) = 0;
 
+#ifdef EATHENA_SUPPORT
         void setNetwork(Network *network);
 
     protected:
         Network *mNetwork;
+#endif
 };
 
-#endif
+typedef const std::auto_ptr<MessageHandler> MessageHandlerPtr;
+
+#endif // NET_MESSAGEHANDLER_H
