@@ -1,6 +1,6 @@
 /*
  *  The Mana World
- *  Copyright (C) 2004  The Mana World Development Team
+ *  Copyright (C) 2009  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
@@ -19,17 +19,23 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef NET_SKILLHANDLER_H
-#define NET_SKILLHANDLER_H
+#ifndef SKILLHANDLER_H
+#define SKILLHANDLER_H
 
-#include "messagehandler.h"
+#include <iosfwd>
 
-class SkillHandler : public MessageHandler
+namespace Net {
+class SkillHandler
 {
     public:
-        SkillHandler();
+        virtual void up(int skillId) = 0;
 
-        void handleMessage(MessageIn *msg);
+        virtual void use(int skillId, int level, int beingId) = 0;
+
+        virtual void use(int skillId, int level, int x, int y) = 0;
+
+        virtual void use(int skillId, const std::string &map) = 0;
 };
+}
 
-#endif
+#endif // SKILLHANDLER_H
