@@ -1,6 +1,6 @@
 /*
  *  The Mana World
- *  Copyright (C) 2004  The Mana World Development Team
+ *  Copyright (C) 2009  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
@@ -19,19 +19,33 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef NET_TRADEHANDLER_H
-#define NET_TRADEHANDLER_H
+#ifndef TRADEHANDLER_H
+#define TRADEHANDLER_H
 
-#include "messagehandler.h"
+#include "being.h"
 
-class Network;
+#include <iosfwd>
 
-class TradeHandler : public MessageHandler
+namespace Net {
+class TradeHandler
 {
     public:
-        TradeHandler();
+        virtual void request(Being *being) {}
 
-        void handleMessage(MessageIn *msg);
+        virtual void respond(bool accept) {}
+
+        virtual void addItem(Item *item, int amount) {}
+
+        virtual void removeItem(int slotNum, int amount) {}
+
+        virtual void setMoney(int amount) {}
+
+        virtual void confirm() {}
+
+        virtual void finish() {}
+
+        virtual void cancel() {}
 };
+}
 
-#endif
+#endif // TRADEHANDLER_H
