@@ -22,20 +22,22 @@
 #include <algorithm>
 #include <cmath>
 
-#include "particle.h"
+#include <guichan/color.hpp>
 
 #include "animationparticle.h"
 #include "configuration.h"
 #include "imageparticle.h"
 #include "log.h"
 #include "map.h"
+#include "particle.h"
 #include "particleemitter.h"
+#include "rotationalparticle.h"
 #include "textparticle.h"
 
 #include "resources/resourcemanager.h"
 
 #include "utils/dtor.h"
-#include "utils/fastsqrt.h"
+#include "utils/mathutils.h"
 #include "utils/xml.h"
 
 #define SIN45 0.707106781f
@@ -175,7 +177,8 @@ bool Particle::update()
                 mVelocity *= mBounce;
                 mVelocity.z = -mVelocity.z;
             }
-            else {
+            else
+            {
                 mAlive = false;
             }
         }
@@ -183,16 +186,12 @@ bool Particle::update()
         // Update child emitters
         if ((mLifetimePast-1)%Particle::emitterSkip == 0)
         {
-            for (   EmitterIterator e = mChildEmitters.begin();
-                    e != mChildEmitters.end();
-                    e++
-                )
+            for (EmitterIterator e = mChildEmitters.begin();
+                 e != mChildEmitters.end(); e++)
             {
                 Particles newParticles = (*e)->createParticles(mLifetimePast);
-                for (   ParticleIterator p = newParticles.begin();
-                        p != newParticles.end();
-                        p++
-                    )
+                for (ParticleIterator p = newParticles.begin();
+                     p != newParticles.end(); p++)
                 {
                     (*p)->moveBy(mPos);
                     mChildParticles.push_back (*p);
@@ -217,12 +216,13 @@ bool Particle::update()
         if ((*p)->update())
         {
             p++;
-        } else {
+        }
+        else
+        {
             delete (*p);
             p = mChildParticles.erase(p);
         }
     }
-
     if (!mAlive && mChildParticles.empty() && mAutoDelete)
     {
         return false;
@@ -235,8 +235,7 @@ void Particle::moveBy(const Vector &change)
 {
     mPos += change;
     for (ParticleIterator p = mChildParticles.begin();
-         p != mChildParticles.end();
-         p++)
+         p != mChildParticles.end(); p++)
     {
         if ((*p)->doesFollow())
         {
@@ -251,7 +250,7 @@ void Particle::moveTo(float x, float y)
 }
 
 Particle *Particle::addEffect(const std::string &particleEffectFile,
-                              int pixelX, int pixelY)
+                              int pixelX, int pixelY, int rotation)
 {
     Particle *newParticle = NULL;
 
@@ -277,20 +276,26 @@ Particle *Particle::addEffect(const std::string &particleEffectFile,
         xmlNodePtr node;
 
         // Animation
-        if ((node = XML::findFirstChildByName(
-                        effectChildNode, "animation"))) {
+        if ((node = XML::findFirstChildByName(effectChildNode, "animation")))
+        {
             newParticle = new AnimationParticle(mMap, node);
         }
+        // Rotational
+        else if ((node = XML::findFirstChildByName(effectChildNode, "rotation")))
+        {
+            newParticle = new RotationalParticle(mMap, node);
+        }
         // Image
-        else if ((node = XML::findFirstChildByName(
-                        effectChildNode, "image"))) {
+        else if ((node = XML::findFirstChildByName(effectChildNode, "image")))
+        {
             Image *img= resman->getImage((const char*)
                     node->xmlChildrenNode->content);
 
             newParticle = new ImageParticle(mMap, img);
         }
         // Other
-        else {
+        else
+        {
             newParticle = new Particle(mMap);
         }
 
@@ -313,7 +318,8 @@ Particle *Particle::addEffect(const std::string &particleEffectFile,
                 continue;
 
             ParticleEmitter *newEmitter;
-            newEmitter = new ParticleEmitter(emitterNode, newParticle, mMap);
+            newEmitter = new ParticleEmitter(emitterNode, newParticle, mMap,
+                                             rotation);
             newParticle->addEmitter(newEmitter);
         }
 
@@ -323,12 +329,11 @@ Particle *Particle::addEffect(const std::string &particleEffectFile,
     return newParticle;
 }
 
-Particle *Particle::addTextSplashEffect(const std::string &text,
-                                        int colorR, int colorG, int colorB,
-                                        gcn::Font *font, int x, int y)
+Particle *Particle::addTextSplashEffect(const std::string &text, int x, int y,
+                                        const gcn::Color *color,
+                                        gcn::Font *font, bool outline)
 {
-    Particle *newParticle = new TextParticle(mMap, text, colorR, colorG, colorB,
-                                             font);
+    Particle *newParticle = new TextParticle(mMap, text, color, font, outline);
     newParticle->moveTo(x, y);
     newParticle->setVelocity(((rand() % 100) - 50) / 200.0f,    // X
                              ((rand() % 100) - 50) / 200.0f,    // Y
@@ -344,10 +349,11 @@ Particle *Particle::addTextSplashEffect(const std::string &text,
 }
 
 Particle *Particle::addTextRiseFadeOutEffect(const std::string &text,
-                                             gcn::Font *font,
-                                             int x, int y)
+                                             int x, int y,
+                                             const gcn::Color *color,
+                                             gcn::Font *font, bool outline)
 {
-    Particle *newParticle = new TextParticle(mMap, text, 255, 255, 255, font);
+    Particle *newParticle = new TextParticle(mMap, text, color, font, outline);
     newParticle->moveTo(x, y);
     newParticle->setVelocity(0.0f, 0.0f, 0.5f);
     newParticle->setGravity(0.0015f);
