@@ -19,14 +19,12 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _PARTICLE_H
-#define _PARTICLE_H
+#ifndef PARTICLE_H
+#define PARTICLE_H
 
 #include <list>
 #include <string>
 
-#include <guichan/color.hpp>
-
 #include "guichanfwd.h"
 #include "sprite.h"
 #include "vector.h"
@@ -102,21 +100,21 @@ class Particle : public Sprite
          * particleEffectFile.
          */
         Particle *addEffect(const std::string &particleEffectFile,
-                            int pixelX, int pixelY);
+                            int pixelX, int pixelY, int rotation = 0);
 
         /**
          * Creates a standalone text particle.
          */
-        Particle *addTextSplashEffect(const std::string &text,
-                                      int colorR, int colorG, int colorB,
-                                      gcn::Font *font, int x, int y);
+        Particle *addTextSplashEffect(const std::string &text, int x, int y,
+                const gcn::Color *color, gcn::Font *font,
+                bool outline = false);
 
         /**
          * Creates a standalone text particle.
          */
         Particle *addTextRiseFadeOutEffect(const std::string &text,
-                                           gcn::Font *font,
-                                           int x, int y);
+                int x, int y, const gcn::Color *color, gcn::Font *font,
+                bool outline = false);
 
         /**
          * Adds an emitter to the particle.
@@ -269,7 +267,6 @@ class Particle : public Sprite
         int mFadeIn;                /**< Age in game ticks where fading in is finished*/
         float mAlpha;               /**< Opacity of the graphical representation of the particle */
 
-    private:
         // generic properties
         bool mAutoDelete;           /**< May the particle request its deletion by the parent particle? */
         Map *mMap;                  /**< Map the particle is on. */
@@ -286,7 +283,7 @@ class Particle : public Sprite
 
         // follow-point particles
         Particle *mTarget;          /**< The particle that attracts this particle*/
-        float mAcceleration;        /**< Acceleration towards the target particle in pixels per game-tick²*/
+        float mAcceleration;        /**< Acceleration towards the target particle in pixels per game-tick*/
         float mInvDieDistance;      /**< Distance in pixels from the target particle that causes the destruction of the particle*/
         float mMomentum;            /**< How much speed the particle retains after each game tick*/
 };
