@@ -19,14 +19,13 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _PARTICLE_CONTAINER_H
-#define _PARTICLE_CONTAINER_H
+#ifndef PARTICLE_CONTAINER_H
+#define PARTICLE_CONTAINER_H
 
 #include <list>
 #include <vector>
 
-#include "particle.h"
-
+class Particle;
 
 /**
  * Set of particle effects.  May be stacked with other ParticleContainers.  All
@@ -53,7 +52,7 @@ public:
     /**
      * Kills and removes all particle effects (only in this container)
      */
-    virtual void clearLocally() {};
+    virtual void clearLocally() {}
 
     /**
      * Sets the positions of all elements
@@ -65,8 +64,6 @@ protected:
     ParticleContainer *mNext;           /**< Contained container, if any */
 };
 
-
-
 /**
  * Linked list of particle effects.
  */
@@ -94,7 +91,6 @@ protected:
     std::list<Particle *> mElements;    /**< Contained particle effects */
 };
 
-
 /**
  * Particle container with indexing facilities
  */
