@@ -19,31 +19,30 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "particleemitter.h"
+#include <cmath>
 
 #include "animationparticle.h"
 #include "imageparticle.h"
 #include "log.h"
 #include "particle.h"
+#include "particleemitter.h"
+#include "rotationalparticle.h"
 
-#include "resources/animation.h"
 #include "resources/image.h"
-#include "resources/resourcemanager.h"
 #include "resources/imageset.h"
-
-#include <cmath>
+#include "resources/resourcemanager.h"
 
 #define SIN45 0.707106781f
 #define DEG_RAD_FACTOR 0.017453293f
 
-ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *map):
+ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *map, int rotation):
     mOutputPauseLeft(0),
     mParticleImage(0)
 {
     mMap = map;
     mParticleTarget = target;
 
-    //initializing default values
+    // Initializing default values
     mParticlePosX.set(0.0f);
     mParticlePosY.set(0.0f);
     mParticlePosZ.set(0.0f);
@@ -93,7 +92,7 @@ ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *
             {
                 std::string image = XML::getProperty(propertyNode, "value", "");
                 // Don't leak when multiple images are defined
-                if (image != "" && !mParticleImage)
+                if (!image.empty() && !mParticleImage)
                 {
                     ResourceManager *resman = ResourceManager::getInstance();
                     mParticleImage = resman->getImage(image);
@@ -102,7 +101,9 @@ ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *
             else if (name == "horizontal-angle")
             {
                 mParticleAngleHorizontal = readParticleEmitterProp(propertyNode, 0.0f);
+                mParticleAngleHorizontal.minVal += rotation;
                 mParticleAngleHorizontal.minVal *= DEG_RAD_FACTOR;
+                mParticleAngleHorizontal.maxVal += rotation;
                 mParticleAngleHorizontal.maxVal *= DEG_RAD_FACTOR;
                 mParticleAngleHorizontal.changeAmplitude *= DEG_RAD_FACTOR;
             }
@@ -184,6 +185,74 @@ ParticleEmitter::ParticleEmitter(xmlNodePtr emitterNode, Particle *target, Map *
             ParticleEmitter newEmitter(propertyNode, mParticleTarget, map);
             mParticleChildEmitters.push_back(newEmitter);
         }
+        else if (xmlStrEqual(propertyNode->name, BAD_CAST "rotation"))
+        {
+            ImageSet *imageset = ResourceManager::getInstance()->getImageSet(
+                XML::getProperty(propertyNode, "imageset", ""),
+                XML::getProperty(propertyNode, "width", 0),
+                XML::getProperty(propertyNode, "height", 0)
+            );
+
+            // Get animation frames
+            for_each_xml_child_node(frameNode, propertyNode)
+            {
+                int delay = XML::getProperty(frameNode, "delay", 0);
+                int offsetX = XML::getProperty(frameNode, "offsetX", 0);
+                int offsetY = XML::getProperty(frameNode, "offsetY", 0);
+                offsetY -= imageset->getHeight() - 32;
+                offsetX -= imageset->getWidth() / 2 - 16;
+
+                if (xmlStrEqual(frameNode->name, BAD_CAST "frame"))
+                {
+                    int index = XML::getProperty(frameNode, "index", -1);
+
+                    if (index < 0)
+                    {
+                        logger->log("No valid value for 'index'");
+                        continue;
+                    }
+
+                    Image *img = imageset->get(index);
+
+                    if (!img)
+                    {
+                        logger->log("No image at index %d", index);
+                        continue;
+                    }
+
+                    mParticleRotation.addFrame(img, delay, offsetX, offsetY);
+                }
+                else if (xmlStrEqual(frameNode->name, BAD_CAST "sequence"))
+                {
+                    int start = XML::getProperty(frameNode, "start", -1);
+                    int end = XML::getProperty(frameNode, "end", -1);
+
+                    if (start < 0 || end < 0)
+                    {
+                        logger->log("No valid value for 'start' or 'end'");
+                        continue;
+                    }
+
+                    while (end >= start)
+                    {
+                        Image *img = imageset->get(start);
+
+                        if (!img)
+                        {
+                            logger->log("No image at index %d", start);
+                            continue;
+                        }
+
+                        mParticleRotation.addFrame(img, delay, offsetX, offsetY);
+                        start++;
+                    }
+                }
+                else if (xmlStrEqual(frameNode->name, BAD_CAST "end"))
+                {
+                    mParticleRotation.addTerminator();
+                }
+            } // for frameNode
+        }
         else if (xmlStrEqual(propertyNode->name, BAD_CAST "animation"))
         {
             ImageSet *imageset = ResourceManager::getInstance()->getImageSet(
@@ -285,6 +354,7 @@ ParticleEmitter & ParticleEmitter::operator=(const ParticleEmitter &o)
     mOutputPause = o.mOutputPause;
     mParticleImage = o.mParticleImage;
     mParticleAnimation = o.mParticleAnimation;
+    mParticleRotation = o.mParticleRotation;
     mParticleChildEmitters = o.mParticleChildEmitters;
 
     mOutputPauseLeft = 0;
@@ -310,26 +380,25 @@ ParticleEmitter::readParticleEmitterProp(xmlNodePtr propertyNode, T def)
     retval.set((T) XML::getFloatProperty(propertyNode, "min", (double) def),
                (T) XML::getFloatProperty(propertyNode, "max", (double) def));
 
-    std::string change = XML::getProperty(propertyNode, "change-func", "none");
-    T amplitude = (T) XML::getFloatProperty(propertyNode, "change-amplitude", 0.0);
-    int period = XML::getProperty(propertyNode, "change-period", 0);
-    int phase = XML::getProperty(propertyNode, "change-phase", 0);
-    if (change == "saw" || change == "sawtooth") {
-        retval.setFunction(FUNC_SAW, amplitude, period, phase);
-    } else if (change == "sine" || change == "sinewave") {
-        retval.setFunction(FUNC_SINE, amplitude, period, phase);
-    } else if (change == "triangle") {
-        retval.setFunction(FUNC_TRIANGLE, amplitude, period, phase);
-    } else if (change == "square"){
-        retval.setFunction(FUNC_SQUARE, amplitude, period, phase);
-    }
+     std::string change = XML::getProperty(propertyNode, "change-func", "none");
+     T amplitude = (T) XML::getFloatProperty(propertyNode, "change-amplitude", 0.0);
+     int period = XML::getProperty(propertyNode, "change-period", 0);
+     int phase = XML::getProperty(propertyNode, "change-phase", 0);
+     if (change == "saw" || change == "sawtooth") {
+         retval.setFunction(FUNC_SAW, amplitude, period, phase);
+     } else if (change == "sine" || change == "sinewave") {
+         retval.setFunction(FUNC_SINE, amplitude, period, phase);
+     } else if (change == "triangle") {
+         retval.setFunction(FUNC_TRIANGLE, amplitude, period, phase);
+     } else if (change == "square"){
+         retval.setFunction(FUNC_SQUARE, amplitude, period, phase);
+     }
 
     return retval;
 }
 
 
-std::list<Particle *>
-ParticleEmitter::createParticles(int tick)
+std::list<Particle *> ParticleEmitter::createParticles(int tick)
 {
     std::list<Particle *> newParticles;
 
@@ -350,6 +419,11 @@ ParticleEmitter::createParticles(int tick)
         {
             newParticle = new ImageParticle(mMap, mParticleImage);
         }
+        else if (mParticleRotation.getLength() > 0)
+        {
+            Animation *newAnimation = new Animation(mParticleRotation);
+            newParticle = new RotationalParticle(mMap, newAnimation);
+        }
         else if (mParticleAnimation.getLength() > 0)
         {
             Animation *newAnimation = new Animation(mParticleAnimation);
