@@ -19,17 +19,17 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _PARTICLEEMITTER_H
-#define _PARTICLEEMITTER_H
+#ifndef PARTICLEEMITTER_H
+#define PARTICLEEMITTER_H
 
 #include <list>
 
 #include "utils/xml.h"
 
-#include "resources/animation.h"
-
 #include "particleemitterprop.h"
 
+#include "resources/animation.h"
+
 class Image;
 class Map;
 class Particle;
@@ -44,7 +44,7 @@ class ParticleEmitter
         /**
          * Constructor.
          */
-        ParticleEmitter(xmlNodePtr emitterNode,  Particle *target, Map *map);
+        ParticleEmitter(xmlNodePtr emitterNode,  Particle *target, Map *map, int rotation = 0);
 
         /**
          * Copy Constructor (necessary for reference counting of particle images)
@@ -70,8 +70,7 @@ class ParticleEmitter
         /**
          * Sets the target of the particles that are created
          */
-        void
-        setTarget(Particle *target)
+        void setTarget(Particle *target)
         { mParticleTarget = target; };
 
     private:
@@ -126,6 +125,7 @@ class ParticleEmitter
          */
         Image *mParticleImage; /**< Particle image, if used */
         Animation mParticleAnimation; /**< Filename of particle animation file */
+        Animation mParticleRotation; /**< Filename of particle rotation file */
         ParticleEmitterProp<float> mParticleAlpha; /**< Opacity of the graphical representation of the particles */
 
         /** List of emitters the spawned particles are equipped with */
