@@ -19,17 +19,17 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <algorithm>
+#include "resources/dye.h"
+
+#include "log.h"
+
 #include <sstream>
 
-#include "dye.h"
-
-#include "../log.h"
-
-Palette::Palette(const std::string &description)
+DyePalette::DyePalette(const std::string &description)
 {
     int size = description.length();
-    if (size == 0) return;
+    if (size == 0)
+        return;
     if (description[0] != '#')
     {
         // TODO: load palette from file.
@@ -39,23 +39,35 @@ Palette::Palette(const std::string &description)
     int pos = 1;
     for (;;)
     {
-        if (pos + 6 > size) break;
+        if (pos + 6 > size)
+            break;
+
         int v = 0;
         for (int i = 0; i < 6; ++i)
         {
             char c = description[pos + i];
             int n;
-            if ('0' <= c && c <= '9') n = c - '0';
-            else if ('A' <= c && c <= 'F') n = c - 'A' + 10;
-            else if ('a' <= c && c <= 'f') n = c - 'a' + 10;
-            else goto error;
+
+            if ('0' <= c && c <= '9')
+                n = c - '0';
+            else if ('A' <= c && c <= 'F')
+                n = c - 'A' + 10;
+            else if ('a' <= c && c <= 'f')
+                n = c - 'a' + 10;
+            else
+                goto error;
+
             v = (v << 4) | n;
         }
         Color c = { { v >> 16, v >> 8, v } };
         mColors.push_back(c);
         pos += 6;
-        if (pos == size) return;
-        if (description[pos] != ',') break;
+
+        if (pos == size)
+            return;
+        if (description[pos] != ',')
+            break;
+
         ++pos;
     }
 
@@ -63,7 +75,7 @@ Palette::Palette(const std::string &description)
     logger->log("Error, invalid embedded palette: %s", description.c_str());
 }
 
-void Palette::getColor(int intensity, int color[3]) const
+void DyePalette::getColor(int intensity, int color[3]) const
 {
     if (intensity == 0)
     {
@@ -112,23 +124,28 @@ void Palette::getColor(int intensity, int color[3]) const
 Dye::Dye(const std::string &description)
 {
     for (int i = 0; i < 7; ++i)
-        mPalettes[i] = 0;
+        mDyePalettes[i] = 0;
 
-    if (description.empty()) return;
+    if (description.empty())
+        return;
 
     std::string::size_type next_pos = 0, length = description.length();
     do
     {
         std::string::size_type pos = next_pos;
         next_pos = description.find(';', pos);
+
         if (next_pos == std::string::npos)
             next_pos = length;
+
         if (next_pos <= pos + 3 || description[pos + 1] != ':')
         {
             logger->log("Error, invalid dye: %s", description.c_str());
             return;
         }
+
         int i = 0;
+
         switch (description[pos])
         {
             case 'R': i = 0; break;
@@ -142,7 +159,8 @@ Dye::Dye(const std::string &description)
                 logger->log("Error, invalid dye: %s", description.c_str());
                 return;
         }
-        mPalettes[i] = new Palette(description.substr(pos + 2, next_pos - pos - 2));
+        mDyePalettes[i] = new DyePalette(description.substr(pos + 2,
+                                                            next_pos - pos - 2));
         ++next_pos;
     }
     while (next_pos < length);
@@ -151,13 +169,14 @@ Dye::Dye(const std::string &description)
 Dye::~Dye()
 {
     for (int i = 0; i < 7; ++i)
-        delete mPalettes[i];
+        delete mDyePalettes[i];
 }
 
 void Dye::update(int color[3]) const
 {
     int cmax = std::max(color[0], std::max(color[1], color[2]));
-    if (cmax == 0) return;
+    if (cmax == 0)
+        return;
 
     int cmin = std::min(color[0], std::min(color[1], color[2]));
     int intensity = color[0] + color[1] + color[2];
@@ -171,14 +190,17 @@ void Dye::update(int color[3]) const
 
     int i = (color[0] != 0) | ((color[1] != 0) << 1) | ((color[2] != 0) << 2);
 
-    if (mPalettes[i - 1])
-        mPalettes[i - 1]->getColor(cmax, color);
+    if (mDyePalettes[i - 1])
+        mDyePalettes[i - 1]->getColor(cmax, color);
 }
 
 void Dye::instantiate(std::string &target, const std::string &palettes)
 {
     std::string::size_type next_pos = target.find('|');
-    if (next_pos == std::string::npos || palettes.empty()) return;
+
+    if (next_pos == std::string::npos || palettes.empty())
+        return;
+
     ++next_pos;
 
     std::ostringstream s;
@@ -188,7 +210,10 @@ void Dye::instantiate(std::string &target, const std::string &palettes)
     {
         std::string::size_type pos = next_pos;
         next_pos = target.find(';', pos);
-        if (next_pos == std::string::npos) next_pos = last_pos;
+
+        if (next_pos == std::string::npos)
+            next_pos = last_pos;
+
         if (next_pos == pos + 1 && pal_pos != std::string::npos)
         {
             std::string::size_type pal_next_pos = palettes.find(';', pal_pos);
