@@ -19,13 +19,13 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "imageset.h"
+#include "resources/imageset.h"
 
-#include "../log.h"
+#include "resources/image.h"
 
-#include "image.h"
+#include "log.h"
 
-#include "../utils/dtor.h"
+#include "utils/dtor.h"
 
 ImageSet::ImageSet(Image *img, int width, int height)
 {
@@ -45,8 +45,7 @@ ImageSet::~ImageSet()
     delete_all(mImages);
 }
 
-Image*
-ImageSet::get(size_type i) const
+Image* ImageSet::get(size_type i) const
 {
     if (i >= mImages.size())
     {
