@@ -22,12 +22,14 @@
 #ifndef ITEM_MANAGER_H
 #define ITEM_MANAGER_H
 
-#include "iteminfo.h"
-
+#include <list>
 #include <map>
+#include <string>
+
+class ItemInfo;
 
 /**
- * The namespace that holds the item information.
+ * Item information database.
  */
 namespace ItemDB
 {
@@ -41,11 +43,26 @@ namespace ItemDB
      */
     void unload();
 
-    const ItemInfo& get(int id);
+    const ItemInfo &get(int id);
+    const ItemInfo &get(const std::string &name);
+
+    struct Stat
+    {
+        Stat(const std::string &tag,
+             const std::string &format):
+            tag(tag),
+            format(format)
+        {}
+
+        std::string tag;
+        std::string format;
+    };
+
+    void setStatsList(const std::list<Stat> &stats);
 
     // Items database
     typedef std::map<int, ItemInfo*> ItemInfos;
-    typedef ItemInfos::iterator ItemInfoIterator;
+    typedef std::map<std::string, ItemInfo*> NamedItemInfos;
 }
 
 #endif
