@@ -19,23 +19,23 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "mapreader.h"
+#include "resources/animation.h"
+#include "resources/image.h"
+#include "resources/mapreader.h"
+#include "resources/resourcemanager.h"
+
+#include "log.h"
+#include "map.h"
+#include "tileset.h"
+
+#include "utils/base64.h"
+#include "utils/stringutils.h"
+#include "utils/xml.h"
 
 #include <cassert>
 #include <iostream>
 #include <zlib.h>
 
-#include "resourcemanager.h"
-#include "image.h"
-
-#include "../log.h"
-#include "../map.h"
-#include "../tileset.h"
-
-#include "../utils/base64.h"
-#include "../utils/tostring.h"
-#include "../utils/xml.h"
-
 const unsigned int DEFAULT_TILE_WIDTH = 32;
 const unsigned int DEFAULT_TILE_HEIGHT = 32;
 
@@ -143,6 +143,7 @@ int inflateMemory(unsigned char *in, unsigned int inLength,
 
 Map *MapReader::readMap(const std::string &filename)
 {
+    logger->log("Attempting to read map %s", filename.c_str());
     // Load the file through resource manager
     ResourceManager *resman = ResourceManager::getInstance();
     int fileSize;
@@ -205,14 +206,11 @@ Map *MapReader::readMap(xmlNodePtr node, const std::string &path)
     // Take the filename off the path
     const std::string pathDir = path.substr(0, path.rfind("/") + 1);
 
-    //xmlChar *prop = xmlGetProp(node, BAD_CAST "version");
-    //xmlFree(prop);
-
     const int w = XML::getProperty(node, "width", 0);
     const int h = XML::getProperty(node, "height", 0);
-    const int tw = XML::getProperty(node, "tilewidth", DEFAULT_TILE_WIDTH);
-    const int th = XML::getProperty(node, "tileheight", DEFAULT_TILE_HEIGHT);
-    Map *map = new Map(w, h, tw, th);
+    const int tilew = XML::getProperty(node, "tilewidth", DEFAULT_TILE_WIDTH);
+    const int tileh = XML::getProperty(node, "tileheight", DEFAULT_TILE_HEIGHT);
+    Map *map = new Map(w, h, tilew, tileh);
 
     for_each_xml_child_node(childNode, node)
     {
@@ -236,8 +234,8 @@ Map *MapReader::readMap(xmlNodePtr node, const std::string &path)
             // The object group offset is applied to each object individually
             const int tileOffsetX = XML::getProperty(childNode, "x", 0);
             const int tileOffsetY = XML::getProperty(childNode, "y", 0);
-            const int offsetX = tileOffsetX * tw;
-            const int offsetY = tileOffsetY * th;
+            const int offsetX = tileOffsetX * tilew;
+            const int offsetY = tileOffsetY * tileh;
 
             for_each_xml_child_node(objectNode, childNode)
             {
@@ -313,7 +311,8 @@ static void setTile(Map *map, MapLayer *layer, int x, int y, int gid)
         layer->setTile(x, y, img);
     } else {
         // Set collision tile
-        map->setWalk(x, y, (!set || (gid - set->getFirstGid() == 0)));
+        if (set && (gid - set->getFirstGid() != 0))
+            map->blockTile(x, y, Map::BLOCKTYPE_WALL);
     }
 }
 
@@ -324,10 +323,11 @@ void MapReader::readLayer(xmlNodePtr node, Map *map)
     const int h = XML::getProperty(node, "height", map->getHeight());
     const int offsetX = XML::getProperty(node, "x", 0);
     const int offsetY = XML::getProperty(node, "y", 0);
-    const std::string name = XML::getProperty(node, "name", "");
+    std::string name = XML::getProperty(node, "name", "");
+    name = toLower(name);
 
-    const bool isFringeLayer = (name == "Fringe");
-    const bool isCollisionLayer = (name == "Collision");
+    const bool isFringeLayer = (name.substr(0,6) == "fringe");
+    const bool isCollisionLayer = (name.substr(0,9) == "collision");
 
     MapLayer *layer = 0;
 
@@ -370,7 +370,7 @@ void MapReader::readLayer(xmlNodePtr node, Map *map)
 
             while (*charStart) {
                 if (*charStart != ' ' && *charStart != '\t' &&
-                        *charStart != '\n')
+                    *charStart != '\n')
                 {
                     *charIndex = *charStart;
                     charIndex++;
@@ -461,15 +461,20 @@ Tileset *MapReader::readTileset(xmlNodePtr node,
                                 const std::string &path,
                                 Map *map)
 {
+    int firstGid = XML::getProperty(node, "firstgid", 0);
+    XML::Document* doc = NULL;
     Tileset *set = NULL;
 
     if (xmlHasProp(node, BAD_CAST "source"))
     {
-        logger->log("Warning: External tilesets not supported yet.");
-        return set;
+        std::string filename = XML::getProperty(node, "source", "");
+        while (filename.substr(0, 3) == "../")
+               filename.erase(0, 3);  // Remove "../"
+        doc = new XML::Document(filename);
+        node = doc->rootNode();
+        firstGid += XML::getProperty(node, "firstgid", 0);
     }
 
-    const int firstGid = XML::getProperty(node, "firstgid", 0);
     const int tw = XML::getProperty(node, "tilewidth", map->getTileWidth());
     const int th = XML::getProperty(node, "tileheight", map->getTileHeight());
 
@@ -520,7 +525,7 @@ Tileset *MapReader::readTileset(xmlNodePtr node,
                 // create animation
                 if (!set) continue;
 
-                Animation *ani = new Animation();
+                Animation *ani = new Animation;
                 for (int i = 0; ;i++)
                 {
                     std::map<std::string, int>::iterator iFrame, iDelay;
@@ -545,5 +550,7 @@ Tileset *MapReader::readTileset(xmlNodePtr node,
         }
     }
 
+    delete doc;
+
     return set;
 }
