@@ -19,14 +19,15 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "monsterdb.h"
+#include "resources/monsterdb.h"
 
-#include "resourcemanager.h"
+#include "resources/monsterinfo.h"
 
-#include "../log.h"
+#include "log.h"
 
-#include "../utils/dtor.h"
-#include "../utils/xml.h"
+#include "utils/dtor.h"
+#include "utils/gettext.h"
+#include "utils/xml.h"
 
 namespace
 {
@@ -35,14 +36,13 @@ namespace
     bool mLoaded = false;
 }
 
-void
-MonsterDB::load()
+void MonsterDB::load()
 {
     if (mLoaded)
         return;
 
     mUnknown.addSprite("error.xml");
-    mUnknown.setName("unnamed");
+    mUnknown.setName(_("unnamed"));
 
     logger->log("Initializing monster database...");
 
@@ -62,9 +62,9 @@ MonsterDB::load()
             continue;
         }
 
-        MonsterInfo *currentInfo = new MonsterInfo();
+        MonsterInfo *currentInfo = new MonsterInfo;
 
-        currentInfo->setName (XML::getProperty(monsterNode, "name", "unnamed"));
+        currentInfo->setName(XML::getProperty(monsterNode, "name", _("unnamed")));
 
         std::string targetCursor;
         targetCursor = XML::getProperty(monsterNode, "targetCursor", "medium");
@@ -82,7 +82,8 @@ MonsterDB::load()
         }
         else
         {
-            logger->log("MonsterDB: Unknown target cursor type \"%s\" for %s - using medium sized one",
+            logger->log("MonsterDB: Unknown target cursor type \"%s\" for %s -"
+                        "using medium sized one",
                         targetCursor.c_str(), currentInfo->getName().c_str());
             currentInfo->setTargetCursorSize(Being::TC_MEDIUM);
         }
@@ -92,10 +93,10 @@ MonsterDB::load()
         {
             if (xmlStrEqual(spriteNode->name, BAD_CAST "sprite"))
             {
-                currentInfo->addSprite((const char*) spriteNode->xmlChildrenNode->content);
+                currentInfo->addSprite(
+                        (const char*) spriteNode->xmlChildrenNode->content);
             }
-
-            if (xmlStrEqual(spriteNode->name, BAD_CAST "sound"))
+            else if (xmlStrEqual(spriteNode->name, BAD_CAST "sound"))
             {
                 std::string event = XML::getProperty(spriteNode, "event", "");
                 const char *filename;
@@ -119,12 +120,22 @@ MonsterDB::load()
                 }
                 else
                 {
-                    logger->log("MonsterDB: Warning, sound effect %s for unknown event %s of monster %s",
-                                filename, event.c_str(), currentInfo->getName().c_str());
+                    logger->log("MonsterDB: Warning, sound effect %s for "
+                                "unknown event %s of monster %s",
+                                filename, event.c_str(),
+                                currentInfo->getName().c_str());
                 }
             }
-
-            if (xmlStrEqual(spriteNode->name, BAD_CAST "particlefx"))
+            else if (xmlStrEqual(spriteNode->name, BAD_CAST "attack"))
+            {
+                const int id = XML::getProperty(spriteNode, "id", 0);
+                const std::string particleEffect = XML::getProperty(
+                        spriteNode, "particle-effect", "");
+                SpriteAction spriteAction = SpriteDef::makeSpriteAction(
+                        XML::getProperty(spriteNode, "action", "attack"));
+                currentInfo->addMonsterAttack(id, particleEffect, spriteAction);
+            }
+            else if (xmlStrEqual(spriteNode->name, BAD_CAST "particlefx"))
             {
                 currentInfo->addParticleEffect(
                     (const char*) spriteNode->xmlChildrenNode->content);
