@@ -24,20 +24,18 @@
 
 #include <map>
 
-#include "monsterinfo.h"
+class MonsterInfo;
 
 /**
  * Monster information database.
  */
 namespace MonsterDB
 {
-    void
-    load();
+    void load();
 
-    void
-    unload();
+    void unload();
 
-    const MonsterInfo& get(int id);
+    const MonsterInfo &get(int id);
 
     typedef std::map<int, MonsterInfo*> MonsterInfos;
     typedef MonsterInfos::iterator MonsterInfoIterator;
