@@ -22,9 +22,13 @@
 #ifndef MUSIC_H
 #define MUSIC_H
 
-#include <SDL_mixer.h>
+#include "resources/resource.h"
 
-#include "resource.h"
+#ifdef __APPLE__
+#include <SDL_mixer/SDL_mixer.h>
+#else
+#include <SDL_mixer.h>
+#endif
 
 /**
  * Defines a class for loading and storing music.
@@ -56,14 +60,12 @@ class Music : public Resource
          * @return <code>true</code> if the playback started properly
          *         <code>false</code> otherwise.
          */
-        virtual bool
-        play(int loops);
+        virtual bool play(int loops);
 
         /**
          * Stops the music.
          */
-        virtual void
-        stop();
+        virtual void stop();
 
     protected:
         /**
