@@ -19,24 +19,22 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "resources/resource.h"
+
+#include "resources/resourcemanager.h"
+
 #include <cassert>
 
-#include "resource.h"
-
-#include "resourcemanager.h"
-
 Resource::~Resource()
 {
 }
 
-void
-Resource::incRef()
+void Resource::incRef()
 {
     mRefCount++;
 }
 
-void
-Resource::decRef()
+void Resource::decRef()
 {
     // Reference may not already have reached zero
     assert(mRefCount != 0);
