@@ -19,24 +19,23 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <cassert>
-#include <sstream>
-#include <sys/time.h>
+#include "resources/resourcemanager.h"
 
+#include "resources/dye.h"
+#include "resources/image.h"
+#include "resources/imageset.h"
+#include "resources/music.h"
+#include "resources/soundeffect.h"
+#include "resources/spritedef.h"
+
+#include "log.h"
+
+#include <cassert>
 #include <physfs.h>
 #include <SDL_image.h>
+#include <sstream>
 
-#include "resourcemanager.h"
-
-#include "dye.h"
-#include "image.h"
-#include "music.h"
-#include "soundeffect.h"
-#include "imageset.h"
-#include "spritedef.h"
-
-#include "../log.h"
-
+#include <sys/time.h>
 
 ResourceManager *ResourceManager::instance = NULL;
 
@@ -155,13 +154,13 @@ bool ResourceManager::addToSearchPath(const std::string &path, bool append)
 }
 
 void ResourceManager::searchAndAddArchives(const std::string &path,
-                                      const std::string &ext,
-                                      bool append)
+                                           const std::string &ext,
+                                           bool append)
 {
     const char *dirSep = PHYSFS_getDirSeparator();
     char **list = PHYSFS_enumerateFiles(path.c_str());
 
-    for (char **i = list; *i != NULL; i++)
+    for (char **i = list; *i; i++)
     {
         size_t len = strlen(*i);
 
@@ -209,7 +208,7 @@ std::string ResourceManager::getPath(const std::string &file)
     else
     {
         // if not found in search path return the default path
-        path = std::string(TMW_DATADIR) + std::string("data") + "/" + file;
+        path = std::string(PKG_DATADIR) + std::string("data") + "/" + file;
     }
 
     return path;
@@ -381,7 +380,7 @@ ResourceManager *ResourceManager::getInstance()
 {
     // Create a new instance if necessary.
     if (!instance)
-        instance = new ResourceManager();
+        instance = new ResourceManager;
     return instance;
 }
 
@@ -420,8 +419,35 @@ void *ResourceManager::loadFile(const std::string &fileName, int &fileSize)
     return buffer;
 }
 
-std::vector<std::string>
-ResourceManager::loadTextFile(const std::string &fileName)
+bool ResourceManager::copyFile(const std::string &src, const std::string &dst)
+{
+    PHYSFS_file *srcFile = PHYSFS_openRead(src.c_str());
+    if (!srcFile)
+    {
+        logger->log("Read error: %s", PHYSFS_getLastError());
+        return false;
+    }
+    PHYSFS_file *dstFile = PHYSFS_openWrite(dst.c_str());
+    if (!dstFile)
+    {
+        logger->log("Write error: %s", PHYSFS_getLastError());
+        PHYSFS_close(srcFile);
+        return false;
+    }
+
+    int fileSize = PHYSFS_fileLength(srcFile);
+    void *buf = malloc(fileSize);
+    PHYSFS_read(srcFile, buf, 1, fileSize);
+    PHYSFS_write(dstFile, buf, 1, fileSize);
+
+    PHYSFS_close(srcFile);
+    PHYSFS_close(dstFile);
+    free(buf);
+    return true;
+}
+
+std::vector<std::string> ResourceManager::loadTextFile(
+        const std::string &fileName)
 {
     int contentsLength;
     char *fileContents = (char*)loadFile(fileName, contentsLength);
@@ -443,7 +469,7 @@ ResourceManager::loadTextFile(const std::string &fileName)
     return lines;
 }
 
-SDL_Surface *ResourceManager::loadSDLSurface(const std::string& filename)
+SDL_Surface *ResourceManager::loadSDLSurface(const std::string &filename)
 {
     int fileSize;
     void *buffer = loadFile(filename, fileSize);
