@@ -27,11 +27,11 @@
 #include <string>
 #include <vector>
 
-class Resource;
 class Image;
-class Music;
-class SoundEffect;
 class ImageSet;
+class Music;
+class Resource;
+class SoundEffect;
 class SpriteDef;
 struct SDL_Surface;
 
@@ -40,7 +40,6 @@ struct SDL_Surface;
  */
 class ResourceManager
 {
-
     friend class Resource;
 
     public:
@@ -48,13 +47,11 @@ class ResourceManager
         typedef Resource *(*loader)(void *, unsigned);
         typedef Resource *(*generator)(void *);
 
-        /**
-         * Constructor.
-         */
         ResourceManager();
 
         /**
-         * Destructor.
+         * Destructor. Cleans up remaining resources, warning about resources
+         * that were still referenced.
          */
         ~ResourceManager();
 
@@ -100,7 +97,7 @@ class ResourceManager
         /**
          * Returns the real path to a file. Note that this method will always
          * return a path, it does not check whether the file exists.
-         * 
+         *
          * @param file The file to get the real path to.
          * @return The real path.
          */
@@ -127,6 +124,17 @@ class ResourceManager
          */
         Resource *load(const std::string &path, loader fun);
 
+        /**
+        * Copies a file from one place to another (useful for extracting
+        * raw files from a zip archive, for example)
+        *
+        * @param src Source file name
+        * @param dst Destination file name
+        * @return true on success, false on failure. An error message should be
+        *         in the log file.
+        */
+        bool copyFile(const std::string &src, const std::string &dst);
+
         /**
          * Convenience wrapper around ResourceManager::get for loading
          * images.
@@ -183,7 +191,7 @@ class ResourceManager
          * Loads the given filename as an SDL surface. The returned surface is
          * expected to be freed by the caller using SDL_FreeSurface.
          */
-        SDL_Surface *loadSDLSurface(const std::string& filename);
+        SDL_Surface *loadSDLSurface(const std::string &filename);
 
         /**
          * Returns an instance of the class, creating one if it does not
