@@ -19,9 +19,9 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "soundeffect.h"
+#include "resources/soundeffect.h"
 
-#include "../log.h"
+#include "log.h"
 
 SoundEffect::~SoundEffect()
 {
@@ -47,8 +47,7 @@ Resource *SoundEffect::load(void *buffer, unsigned bufferSize)
     }
 }
 
-bool
-SoundEffect::play(int loops, int volume)
+bool SoundEffect::play(int loops, int volume)
 {
     Mix_VolumeChunk(mChunk, volume);
 
