@@ -22,9 +22,13 @@
 #ifndef SOUND_EFFECT_H
 #define SOUND_EFFECT_H
 
-#include <SDL_mixer.h>
+#include "resources/resource.h"
 
-#include "resource.h"
+#ifdef __APPLE__
+#include <SDL_mixer/SDL_mixer.h>
+#else
+#include <SDL_mixer.h>
+#endif
 
 /**
  * Defines a class for loading and storing sound effects.
@@ -35,8 +39,7 @@ class SoundEffect : public Resource
         /**
          * Destructor.
          */
-        virtual
-        ~SoundEffect();
+        virtual ~SoundEffect();
 
         /**
          * Loads a sample from a buffer in memory.
@@ -58,8 +61,7 @@ class SoundEffect : public Resource
          * @return <code>true</code> if the playback started properly
          *         <code>false</code> otherwise.
          */
-        virtual bool
-        play(int loops, int volume);
+        virtual bool play(int loops, int volume);
 
     protected:
         /**
@@ -70,4 +72,4 @@ class SoundEffect : public Resource
         Mix_Chunk *mChunk;
 };
 
-#endif
+#endif // SOUND_EFFECT_H
