@@ -19,20 +19,21 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "resources/spritedef.h"
+
+#include "resources/action.h"
+#include "resources/animation.h"
+#include "resources/dye.h"
+#include "resources/image.h"
+#include "resources/imageset.h"
+#include "resources/resourcemanager.h"
+
+#include "log.h"
+
+#include "utils/xml.h"
+
 #include <set>
 
-#include "spritedef.h"
-
-#include "action.h"
-#include "animation.h"
-#include "dye.h"
-#include "image.h"
-#include "imageset.h"
-#include "resourcemanager.h"
-
-#include "../log.h"
-#include "../utils/xml.h"
-
 Action *SpriteDef::getAction(SpriteAction action) const
 {
     Actions::const_iterator i = mActions.find(action);
@@ -167,7 +168,7 @@ void SpriteDef::loadAction(xmlNodePtr node, int variant_offset)
                 actionName.c_str(), getIdPath().c_str());
         return;
     }
-    Action *action = new Action();
+    Action *action = new Action;
     mActions[actionType] = action;
 
     // When first action set it as default direction
@@ -201,7 +202,7 @@ void SpriteDef::loadAnimation(xmlNodePtr animationNode,
         return;
     }
 
-    Animation *animation = new Animation();
+    Animation *animation = new Animation;
     action->setAnimation(directionType, animation);
 
     // Get animation frames
@@ -322,7 +323,7 @@ SpriteDef::~SpriteDef()
 
 SpriteAction SpriteDef::makeSpriteAction(const std::string &action)
 {
-    if (action == "" || action == "default") {
+    if (action.empty() || action == "default") {
         return ACTION_DEFAULT;
     }
     if (action == "stand") {
@@ -349,6 +350,36 @@ SpriteAction SpriteDef::makeSpriteAction(const std::string &action)
     else if (action == "attack_throw") {
         return ACTION_ATTACK_THROW;
     }
+    else if (action == "special0") {
+        return ACTION_SPECIAL_0;
+    }
+    else if (action == "special1") {
+        return ACTION_SPECIAL_1;
+    }
+    else if (action == "special2") {
+        return ACTION_SPECIAL_2;
+    }
+    else if (action == "special3") {
+        return ACTION_SPECIAL_3;
+    }
+    else if (action == "special4") {
+        return ACTION_SPECIAL_4;
+    }
+    else if (action == "special5") {
+        return ACTION_SPECIAL_5;
+    }
+    else if (action == "special6") {
+        return ACTION_SPECIAL_6;
+    }
+    else if (action == "special7") {
+        return ACTION_SPECIAL_7;
+    }
+    else if (action == "special8") {
+        return ACTION_SPECIAL_8;
+    }
+    else if (action == "special9") {
+        return ACTION_SPECIAL_9;
+    }
     else if (action == "cast_magic") {
         return ACTION_CAST_MAGIC;
     }
@@ -372,9 +403,9 @@ SpriteAction SpriteDef::makeSpriteAction(const std::string &action)
     }
 }
 
-SpriteDirection SpriteDef::makeSpriteDirection(const std::string& direction)
+SpriteDirection SpriteDef::makeSpriteDirection(const std::string &direction)
 {
-    if (direction == "" || direction == "default") {
+    if (direction.empty() || direction == "default") {
         return DIRECTION_DEFAULT;
     }
     else if (direction == "up") {
