@@ -22,11 +22,11 @@
 #ifndef SPRITEDEF_H
 #define SPRITEDEF_H
 
+#include "resources/resource.h"
+
 #include <map>
 #include <string>
 
-#include "resource.h"
-
 #include <libxml/tree.h>
 
 class Action;
@@ -43,6 +43,16 @@ enum SpriteAction
     ACTION_ATTACK_STAB,
     ACTION_ATTACK_BOW,
     ACTION_ATTACK_THROW,
+    ACTION_SPECIAL_0,
+    ACTION_SPECIAL_1,
+    ACTION_SPECIAL_2,
+    ACTION_SPECIAL_3,
+    ACTION_SPECIAL_4,
+    ACTION_SPECIAL_5,
+    ACTION_SPECIAL_6,
+    ACTION_SPECIAL_7,
+    ACTION_SPECIAL_8,
+    ACTION_SPECIAL_9,
     ACTION_CAST_MAGIC,
     ACTION_USE_ITEM,
     ACTION_SIT,
@@ -55,8 +65,8 @@ enum SpriteAction
 enum SpriteDirection
 {
     DIRECTION_DEFAULT = 0,
-    DIRECTION_DOWN,
     DIRECTION_UP,
+    DIRECTION_DOWN,
     DIRECTION_LEFT,
     DIRECTION_RIGHT,
     DIRECTION_INVALID
@@ -89,7 +99,6 @@ class SpriteDef : public Resource
         static SpriteDirection
         makeSpriteDirection(const std::string &direction);
 
-
     private:
         /**
          * Constructor.
@@ -140,7 +149,6 @@ class SpriteDef : public Resource
          */
         void substituteAction(SpriteAction complete, SpriteAction with);
 
-
         typedef std::map<std::string, ImageSet*> ImageSets;
         typedef ImageSets::iterator ImageSetIterator;
 
@@ -150,4 +158,4 @@ class SpriteDef : public Resource
         Actions mActions;
 };
 
-#endif
+#endif // SPRITEDEF_H
