@@ -22,7 +22,11 @@
 #ifndef SOUND_H
 #define SOUND_H
 
+#ifdef __APPLE__
+#include <SDL_mixer/SDL_mixer.h>
+#else
 #include <SDL_mixer.h>
+#endif
 
 #include <string>
 
@@ -30,16 +34,10 @@
  *
  * \ingroup CORE
  */
-class Sound {
+class Sound
+{
     public:
-        /**
-         * Constructor.
-         */
         Sound();
-
-        /**
-         * Destructor.
-         */
         ~Sound();
 
         /**
@@ -47,11 +45,6 @@ class Sound {
          */
         void init();
 
-        /**
-         * Logs various info about sound device.
-         */
-        void info();
-
         /**
          * Removes all sound functionalities.
          */
@@ -61,9 +54,8 @@ class Sound {
          * Starts background music.
          *
          * @param path The full path to the music file.
-         * @param loop The number of times the song is played (-1 = infinite)
          */
-        void playMusic(const std::string &path, int loop = -1);
+        void playMusic(const std::string &path);
 
         /**
          * Stops currently running background music track.
@@ -74,11 +66,9 @@ class Sound {
          * Fades in background music.
          *
          * @param path The full path to the music file.
-         * @param loop The number of times the song is played (-1 = infinite)
          * @param ms   Duration of fade-in effect (ms)
          */
-        void fadeInMusic(const std::string &path, int loop = -1,
-                         int ms = 2000);
+        void fadeInMusic(const std::string &path, int ms = 2000);
 
         /**
          * Fades out currently running background music track.
@@ -87,18 +77,9 @@ class Sound {
          */
         void fadeOutMusic(int ms);
 
-        /**
-         * Sets music volume.
-         *
-         * @param volume Volume value
-         */
-        void setMusicVolume(int volume);
+        int getMaxVolume() const;
 
-        /**
-         * Sets sfx volume.
-         *
-         * @param volume Volume value
-         */
+        void setMusicVolume(int volume);
         void setSfxVolume(int volume);
 
         /**
@@ -109,11 +90,18 @@ class Sound {
         void playSfx(const std::string &path);
 
     private:
+        /** Logs various info about sound device. */
+        void info();
+
+        /** Halts and frees currently playing music. */
+        void haltMusic();
+
         bool mInstalled;
 
         int mSfxVolume;
         int mMusicVolume;
 
+        std::string mCurrentMusicFile;
         Mix_Music *mMusic;
 };
 
