@@ -44,30 +44,26 @@ class Sprite
          * would support setting a translation offset. It already does this
          * partly with the clipping rectangle support.
          */
-        virtual void
-        draw(Graphics *graphics, int offsetX, int offsetY) const = 0;
+        virtual void draw(Graphics *graphics, int offsetX, int offsetY) const = 0;
 
         /**
          * Returns the horizontal size of the sprites graphical representation
          * in pixels or 0 when it is undefined.
          */
-        virtual int
-        getWidth() const
+        virtual int getWidth() const
         { return 0; }
 
         /**
          * Returns the vertical size of the sprites graphical representation
          * in pixels or 0 when it is undefined.
          */
-        virtual int
-        getHeight() const
+        virtual int getHeight() const
         { return 0; }
 
         /**
          * Returns the pixel Y coordinate of the sprite.
          */
-        virtual int
-        getPixelY() const = 0;
+        virtual int getPixelY() const = 0;
 };
 
 #endif
