@@ -21,10 +21,12 @@
 
 #include <map>
 
-#include "gui/chat.h"
 #include "statuseffect.h"
 
 #include "log.h"
+
+#include "gui/widgets/chattab.h"
+
 #include "utils/xml.h"
 
 
@@ -39,19 +41,19 @@ StatusEffect::~StatusEffect()
 
 void StatusEffect::playSFX()
 {
-    if (mSFXEffect != "")
+    if (!mSFXEffect.empty())
         sound.playSfx(mSFXEffect);
 }
 
 void StatusEffect::deliverMessage()
 {
-    if (mMessage != "")
-        chatWindow->chatLog(mMessage, BY_SERVER);
+    if (!mMessage.empty())
+        localChatTab->chatLog(mMessage, BY_SERVER);
 }
 
 Particle *StatusEffect::getParticle()
 {
-    if (mParticleEffect == "")
+    if (mParticleEffect.empty())
         return NULL;
     else
         return particleEngine->addEffect(mParticleEffect, 0, 0);
@@ -59,7 +61,7 @@ Particle *StatusEffect::getParticle()
 
 AnimatedSprite *StatusEffect::getIcon()
 {
-    if (mIcon == "")
+    if (mIcon.empty())
         return NULL;
     else {
         AnimatedSprite *sprite = AnimatedSprite::load(
@@ -74,7 +76,7 @@ AnimatedSprite *StatusEffect::getIcon()
 
 SpriteAction StatusEffect::getAction()
 {
-    if (mAction == "")
+    if (mAction.empty())
         return ACTION_INVALID;
     else
         return SpriteDef::makeSpriteAction(mAction);
@@ -92,7 +94,6 @@ static std::map<int, int> blockEffectIndexMap;
 
 int StatusEffect::blockEffectIndexToEffectIndex(int blockIndex)
 {
-    load();
     if (blockEffectIndexMap.find(blockIndex) == blockEffectIndexMap.end())
         return -1;
     return blockEffectIndexMap[blockIndex];
@@ -100,27 +101,16 @@ int StatusEffect::blockEffectIndexToEffectIndex(int blockIndex)
 
 StatusEffect *StatusEffect::getStatusEffect(int index, bool enabling)
 {
-    load();
     return statusEffects[enabling][index];
 }
 
 StatusEffect *StatusEffect::getStunEffect(int index, bool enabling)
 {
-    load();
     return stunEffects[enabling][index];
 }
 
-static bool status_effects_loaded = false;
-
-
-
 void StatusEffect::load()
 {
-    if (status_effects_loaded)
-        return;
-
-    status_effects_loaded = true;
-
     XML::Document doc(STATUS_EFFECTS_FILE);
     xmlNodePtr rootNode = doc.rootNode();
 
@@ -149,8 +139,8 @@ void StatusEffect::load()
             the_map = &stunEffects;
 
         if (the_map) {
-            StatusEffect *startEffect = new StatusEffect();
-            StatusEffect *endEffect = new StatusEffect();
+            StatusEffect *startEffect = new StatusEffect;
+            StatusEffect *endEffect = new StatusEffect;
 
             startEffect->mMessage = XML::getProperty(node, "start-message", "");
             startEffect->mSFXEffect = XML::getProperty(node, "start-audio", "");
@@ -168,3 +158,19 @@ void StatusEffect::load()
         }
     }
 }
+
+void unloadMap(std::map<int, StatusEffect *> map)
+{
+    std::map<int, StatusEffect *>::iterator it;
+
+    for (it = map.begin(); it != map.end(); it++)
+        delete (*it).second;
+}
+
+void StatusEffect::unload()
+{
+    unloadMap(statusEffects[0]);
+    unloadMap(statusEffects[1]);
+    unloadMap(stunEffects[0]);
+    unloadMap(stunEffects[1]);
+}
