@@ -19,19 +19,20 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <guichan/color.hpp>
+
 #include "textparticle.h"
 
-#include "graphics.h"
+#include "gui/textrenderer.h"
 
 TextParticle::TextParticle(Map *map, const std::string &text,
-                           int colorR, int colorG, int colorB,
-                           gcn::Font *font):
+                           const gcn::Color *color,
+                           gcn::Font *font, bool outline):
     Particle(map),
     mText(text),
     mTextFont(font),
-    mColorR(colorR),
-    mColorG(colorG),
-    mColorB(colorB)
+    mColor(color),
+    mOutline(outline)
 {
 }
 
@@ -46,18 +47,15 @@ void TextParticle::draw(Graphics *graphics, int offsetX, int offsetY) const
     float alpha = mAlpha * 255.0f;
 
     if (mLifetimeLeft > -1 && mLifetimeLeft < mFadeOut)
-    {
-        alpha *= mLifetimeLeft;
-        alpha /= mFadeOut;
-    }
+        alpha = alpha * mLifetimeLeft / mFadeOut;
 
     if (mLifetimePast < mFadeIn)
-    {
-        alpha *= mLifetimePast;
-        alpha /= mFadeIn;
-    }
+        alpha = alpha * mLifetimePast / mFadeIn;
 
-    graphics->setFont(mTextFont);
-    graphics->setColor(gcn::Color(mColorR, mColorG, mColorB, (int)alpha));
-    graphics->drawText(mText, screenX, screenY, gcn::Graphics::CENTER);
+    gcn::Color color = *mColor;
+    color.a = (int) alpha;
+
+    TextRenderer::renderText(graphics, mText,
+            screenX, screenY, gcn::Graphics::CENTER,
+            color, mTextFont, mOutline, false, (int) alpha);
 }
