@@ -26,12 +26,11 @@
    | Author: Jim Winstead (jimw@php.net)                                  |
    +----------------------------------------------------------------------+
    */
-/* $Id: base64.cpp 2906 2006-12-12 15:18:30Z b_lindeijer $ */
 
-#include <string.h>
+#include "utils/base64.h"
+
 #include <stdlib.h>
-
-#include "base64.h"
+#include <string.h>
 
 static char base64_table[] =
 {
